# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\x06\x61llego\x1a\x1fgoogle/protobuf/timestamp.proto\"@\n\x14OfflineLicenseStatus\x12\x12\n\nisVerified\x18\x01 \x02(\x08\x12\x14\n\x0chardwareUUID\x18\x02 \x02(\t\"C\n\x0f\x46irmwareVersion\x12\x0c\n\x04\x64\x61te\x18\x01 \x02(\t\x12\x10\n\x08majorRev\x18\x02 \x02(\x05\x12\x10\n\x08minorRev\x18\x03 \x02(\x05\"k\n\x10RadixEnvironment\x12\x0f\n\x07version\x18\x01 \x02(\t\x12\x14\n\x0cuserDataPath\x18\x02 \x02(\t\x12\x30\n\x0f\x66irmwareVersion\x18\x03 \x02(\x0b\x32\x17.allego.FirmwareVersion\"!\n\x0fStandardRequest\x12\x0e\n\x06regStr\x18\x02 \x03(\t\"/\n\rStandardReply\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\x12\x0e\n\x06regStr\x18\x02 \x03(\t\"&\n\rDACOffRequest\x12\x15\n\rstreamGroupId\x18\x01 \x01(\t\"\xba\x01\n\x13WorkspaceDescriptor\x12\n\n\x02iD\x18\x01 \x02(\t\x12!\n\x03\x61pp\x18\x02 \x02(\x0e\x32\x14.allego.WorkspaceApp\x12\x12\n\nisModified\x18\x03 \x02(\x08\x12\x19\n\x11timestampLastUsed\x18\x04 \x02(\t\x12\x19\n\x11timestampModified\x18\x05 \x02(\t\x12*\n\nannotation\x18\x06 \x02(\x0b\x32\x16.allego.AnnotateBundle\"\xb8\x01\n\x17WorkspaceControlRequest\x12&\n\x03\x63md\x18\x01 \x02(\x0e\x32\x19.allego.WorkspaceCommands\x12\x13\n\x0bworkspaceID\x18\x02 \x01(\t\x12*\n\nannotation\x18\x03 \x01(\x0b\x32\x16.allego.AnnotateBundle\x12\x1a\n\x12targetFullFileName\x18\x04 \x01(\t\x12\x18\n\x10isForceOverwrite\x18\x05 \x01(\x08\"\xd3\x01\n\x13GetWorkspaceRequest\x12)\n\x03\x63md\x18\x01 \x02(\x0e\x32\x1c.allego.GetWorkspaceCommands\x12\x13\n\x0bworkspaceID\x18\x02 \x01(\t\x12\x14\n\x0cworkspaceDir\x18\x03 \x01(\t\x12%\n\x07\x61ppMask\x18\x04 \x01(\x0e\x32\x14.allego.WorkspaceApp\x12,\n\x0c\x61nnotateMask\x18\x05 \x01(\x0b\x32\x16.allego.AnnotateBundle\x12\x11\n\tisBrowser\x18\x06 \x01(\x08\"\xab\x01\n\x11GetWorkspaceReply\x12\x43\n\rworkspaceDesc\x18\x01 \x03(\x0b\x32,.allego.GetWorkspaceReply.WorkspaceDescEntry\x1aQ\n\x12WorkspaceDescEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.allego.WorkspaceDescriptor:\x02\x38\x01\"`\n\x18GetRadiensServersRequest\x12\x15\n\rhostIPaddress\x18\x01 \x02(\t\x12-\n\nserverType\x18\x02 \x01(\x0e\x32\x19.allego.RadiensServerType\"\x97\x02\n\nServerSpec\x12\x0c\n\x04host\x18\x01 \x02(\t\x12\x0b\n\x03pid\x18\x02 \x02(\x05\x12\x30\n\x07service\x18\x03 \x03(\x0b\x32\x1f.allego.ServerSpec.ServiceEntry\x12\x30\n\x05spawn\x18\x04 \x01(\x0b\x32!.allego.ServerSpec.SpawnedProcess\x1a\x1b\n\x0bGrpcService\x12\x0c\n\x04port\x18\x01 \x02(\x05\x1a\x1d\n\x0eSpawnedProcess\x12\x0b\n\x03pid\x18\x01 \x03(\x05\x1aN\n\x0cServiceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.allego.ServerSpec.GrpcService:\x02\x38\x01\"j\n\x13RadiensServersReply\x12(\n\x0c\x61llegoserver\x18\x01 \x03(\x0b\x32\x12.allego.ServerSpec\x12)\n\rradiensserver\x18\x02 \x03(\x0b\x32\x12.allego.ServerSpec\"-\n\x14SignalGroupIDRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\"\xc4\x01\n\tSignalMap\x12\x0f\n\x07siteIdx\x18\x01 \x03(\x05\x12\x13\n\x0b\x63ompSiteNum\x18\x02 \x03(\t\x12\x13\n\x0bposProbeUmX\x18\x03 \x03(\x01\x12\x13\n\x0bposProbeUmY\x18\x04 \x03(\x01\x12\x13\n\x0bposProbeUmZ\x18\x05 \x03(\x01\x12\x14\n\x0cposTissueUmX\x18\x06 \x03(\x01\x12\x14\n\x0cposTissueUmY\x18\x07 \x03(\x01\x12\x14\n\x0cposTissueUmZ\x18\x08 \x03(\x01\x12\x10\n\x08sensorID\x18\t \x03(\t\"=\n\x10GPIOChannelCount\x12\x0c\n\x04nAux\x18\x01 \x02(\x05\x12\x0c\n\x04nDin\x18\x02 \x02(\x05\x12\r\n\x05nDout\x18\x03 \x02(\x05\"D\n\x10PortChannelCount\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x14\n\x0c\x63hannelCount\x18\x02 \x02(\x05\"Q\n\x0eSetPortRequest\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\x12\x10\n\x08probeUID\x18\x02 \x02(\t\x12\x11\n\thstageUID\x18\x03 \x02(\t\"\xe2\x02\n\x11HDSnapshotRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12=\n\npriSignals\x18\x03 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12=\n\nauxSignals\x18\x04 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12=\n\ndinSignals\x18\x05 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x12>\n\x0b\x64outSignals\x18\x06 \x01(\x0b\x32).allego.HDSnapshotRequest.SelectedSignals\x1a&\n\x0fSelectedSignals\x12\x13\n\x0bntvChanIdxs\x18\x01 \x03(\x05\"\x96\x01\n\x12HDSnapshotRequest2\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12)\n\x07selMode\x18\x03 \x01(\x0e\x32\x18.allego.TimeRangeSelMode\x12#\n\x06sigSel\x18\x04 \x01(\x0b\x32\x13.allego.SigSelector\"L\n\x15RadiensPyGraphicsArgs\x12\x12\n\ngraphicsID\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0f\n\x07\x66igSize\x18\x03 \x03(\x03\"\xdd\x02\n\nPSDRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12)\n\x07selMode\x18\x03 \x02(\x0e\x32\x18.allego.TimeRangeSelMode\x12!\n\x05stype\x18\x04 \x02(\x0e\x32\x12.allego.SignalType\x12\x0f\n\x07ntvIdxs\x18\x05 \x03(\x03\x12\x12\n\nresampleFs\x18\x06 \x01(\x01\x12&\n\x07wdwType\x18\x07 \x01(\x0e\x32\x15.allego.PSDWindowType\x12#\n\x07scaling\x18\x08 \x01(\x0e\x32\x12.allego.PSDScaling\x12\x11\n\tfreqRange\x18\t \x03(\x01\x12\x14\n\x0c\x63ollapseFreq\x18\n \x01(\x08\x12\x11\n\tdeltaFreq\x18\x0b \x01(\x01\x12\x0c\n\x04path\x18\r \x01(\t\x12\x13\n\x0bisReturnPSD\x18\x0e \x01(\x08\"\xa1\x02\n\x03PSD\x12\x11\n\tdsourceID\x18\x01 \x01(\t\x12\x1f\n\x02sG\x18\x03 \x02(\x0b\x32\x13.allego.SignalGroup\x12!\n\x05stype\x18\x04 \x02(\x0e\x32\x12.allego.SignalType\x12\x1d\n\x02tR\x18\x05 \x02(\x0b\x32\x11.allego.TimeRange\x12 \n\x03psd\x18\x06 \x02(\x0b\x32\x13.allego.DenseMatrix\x12\x0c\n\x04\x66req\x18\x07 \x03(\x01\x12\x14\n\x0c\x66reqBinWidth\x18\x08 \x02(\x01\x12\x11\n\tfreqRange\x18\x0b \x03(\x01\x12&\n\x07wdwType\x18\t \x01(\x0e\x32\x15.allego.PSDWindowType\x12#\n\x07scaling\x18\n \x01(\x0e\x32\x12.allego.PSDScaling\"e\n\x18RadiensPyGraphicsRequest\x12\x1c\n\x07psdData\x18\x01 \x01(\x0b\x32\x0b.allego.PSD\x12+\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\x1d.allego.RadiensPyGraphicsArgs\"^\n\x0bSigSelector\x12\x12\n\nampNtvIdxs\x18\x01 \x03(\x03\x12\x12\n\nainNtvIdxs\x18\x02 \x03(\x03\x12\x12\n\ndinNtvIdxs\x18\x03 \x03(\x03\x12\x13\n\x0b\x64outNtvIdxs\x18\x04 \x03(\x03\"]\n\x0eHDSnapshotMeta\x12\x11\n\tglobalMin\x18\x04 \x02(\x01\x12\x11\n\tglobalMax\x18\x05 \x02(\x01\x12%\n\x08sigGroup\x18\x06 \x01(\x0b\x32\x13.allego.SignalGroup\"\x9f\x02\n\nHDSnapshot\x12$\n\x04meta\x18\x01 \x02(\x0b\x32\x16.allego.HDSnapshotMeta\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x13\n\x0btimeSamples\x18\x03 \x02(\x0c\x12#\n\x07signals\x18\x04 \x02(\x0b\x32\x12.allego.RawSignals\x12&\n\npriSignals\x18\x05 \x01(\x0b\x32\x12.allego.RawSignals\x12&\n\nauxSignals\x18\x06 \x01(\x0b\x32\x12.allego.RawSignals\x12&\n\ndinSignals\x18\x07 \x01(\x0b\x32\x12.allego.RawSignals\x12\'\n\x0b\x64outSignals\x18\x08 \x01(\x0b\x32\x12.allego.RawSignals\"@\n\x0bHDSnapshot2\x12\x11\n\tdsourceID\x18\x01 \x01(\t\x12\x1e\n\x04sigs\x18\x02 \x02(\x0b\x32\x10.allego.Signals2\"\xb9\x03\n\x11GetSignalsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x37\n\x06params\x18\x02 \x02(\x0b\x32\'.allego.GetSignalsRequest.GetSigsParams\x1a\xd3\x02\n\rGetSigsParams\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x0e\n\x06wdwSec\x18\x02 \x02(\x01\x12\x14\n\x0c\x63hanHeightPx\x18\x03 \x02(\x01\x12\x10\n\x08\x61mpFsrUv\x18\x04 \x02(\x01\x12\x17\n\x0fplotWidthPoints\x18\x05 \x02(\x01\x12\x11\n\tgpioOnTop\x18\x06 \x02(\x08\x12\x0f\n\x07\x61inFsrV\x18\x07 \x02(\x01\x12\x13\n\x0b\x63omponentID\x18\x08 \x02(\t\x12-\n\x0cresampleType\x18\t \x02(\x0e\x32\x17.allego.ResampleRoutine\x12\x11\n\tisHeatmap\x18\n \x02(\x08\x12\x1b\n\x13isNotApplyDSPstage2\x18\x0b \x01(\x08\x12\x13\n\x0b\x63lipToRange\x18\x0c \x02(\x08\x12\x17\n\x0f\x62\x61ndpassLowFreq\x18\r \x01(\x01\x12\x18\n\x10\x62\x61ndpassHighFreq\x18\x0e \x01(\x01\"[\n\nRawSignals\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x0c\n\x04\x64\x61ta\x18\x03 \x02(\x0c\x12\x1d\n\x02tR\x18\x04 \x01(\x0b\x32\x11.allego.TimeRange\"\xe7\x01\n\x08Signals2\x12\x1f\n\x02sG\x18\x01 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12%\n\x03\x61mp\x18\x03 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\x12%\n\x03\x61in\x18\x04 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\x12%\n\x03\x64in\x18\x05 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\x12&\n\x04\x64out\x18\x06 \x01(\x0b\x32\x18.allego.RadixMatrixBytes\"\x85\x02\n\x14ListSensorSpecsReply\x12\x41\n\x06probes\x18\x01 \x03(\x0b\x32\x31.allego.ListSensorSpecsReply.SpecWithChannelCount\x12\x45\n\nheadstages\x18\x02 \x03(\x0b\x32\x31.allego.ListSensorSpecsReply.SpecWithChannelCount\x12\'\n\x05ports\x18\x03 \x03(\x0b\x32\x18.allego.PortChannelCount\x1a:\n\x14SpecWithChannelCount\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x14\n\x0c\x63hannelCount\x18\x02 \x02(\x05\"d\n\x16ListDataSourcesRequest\x12\x11\n\tdirectory\x18\x01 \x02(\t\x12&\n\x06sortBy\x18\x02 \x01(\x0e\x32\x16.allego.DataSourceSort\x12\x0f\n\x07\x64irList\x18\x03 \x03(\t\"\x1c\n\x07SortMap\x12\x11\n\tsorterIds\x18\x01 \x03(\t\">\n\x16GetSignalGroupIDsReply\x12\x12\n\ncontinuous\x18\x01 \x03(\t\x12\x10\n\x08\x64iscrete\x18\x02 \x03(\t\"\xa0\x01\n\x13GetSorterIDMapReply\x12\x43\n\x0csigToSortMap\x18\x01 \x03(\x0b\x32-.allego.GetSorterIDMapReply.SigToSortMapEntry\x1a\x44\n\x11SigToSortMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.allego.SortMap:\x02\x38\x01\"\xaf\x01\n\nDataSource\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x02(\t\x12\x17\n\x0f\x64urationSeconds\x18\x03 \x02(\x01\x12\x17\n\x0f\x64urationMinutes\x18\x04 \x02(\x01\x12\x15\n\rdurationHours\x18\x05 \x02(\x01\x12(\n\x08\x66ileType\x18\x06 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x12\n\nnumSignals\x18\x07 \x02(\x05\"o\n\x0e\x46ileDescriptor\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x13\n\x0b\x66ileNameUID\x18\x04 \x01(\t\"\xd0\x01\n\x08TimeSpec\x12\x30\n\ttimeRange\x18\x01 \x01(\x0b\x32\x1b.allego.TimeSpec.TimeRangeLH\x00\x12:\n\x0etimestampRange\x18\x02 \x01(\x0b\x32 .allego.TimeSpec.TimestampRangeLH\x00\x1a\x1f\n\nTimeRangeL\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x1a)\n\x0fTimestampRangeL\x12\x16\n\x0etimestampRange\x18\x01 \x03(\x03\x42\n\n\x08timeDesc\"\xbe\x01\n\nSignalSpec\x12.\n\x07siteNum\x18\x01 \x01(\x0b\x32\x1b.allego.SignalSpec.SiteNumLH\x00\x12\x34\n\nntvChanIdx\x18\x02 \x01(\x0b\x32\x1e.allego.SignalSpec.NtvChanIdxLH\x00\x1a\x1b\n\x08SiteNumL\x12\x0f\n\x07siteNum\x18\x01 \x03(\x05\x1a!\n\x0bNtvChanIdxL\x12\x12\n\nntvChanIdx\x18\x01 \x03(\x05\x42\n\n\x08siteDesc\"\x8c\x06\n\rChannelRecord\x12\x10\n\x08\x63hanName\x18\x01 \x02(\t\x12$\n\x08\x63hanType\x18\x02 \x02(\x0e\x32\x12.allego.SignalType\x12\x12\n\nntvChanIdx\x18\x03 \x02(\x05\x12\x0f\n\x07siteNum\x18\x04 \x02(\x05\x12\x15\n\rcolorGroupIdx\x18\x05 \x02(\x05\x12\x12\n\nisSelected\x18\x06 \x02(\x08\x12\x13\n\x0bisAudioLeft\x18\x07 \x02(\x08\x12\x1a\n\x04port\x18\x08 \x02(\x0e\x32\x0c.allego.Port\x12\x11\n\tsiteShape\x18\t \x02(\t\x12\x10\n\x08siteCtrX\x18\n \x02(\x01\x12\x10\n\x08siteCtrY\x18\x0b \x02(\x01\x12\x10\n\x08siteCtrZ\x18\x0c \x02(\x01\x12\x13\n\x0bsiteLimXMin\x18\r \x02(\x01\x12\x13\n\x0bsiteLimXMax\x18\x0e \x02(\x01\x12\x13\n\x0bsiteLimYMin\x18\x0f \x02(\x01\x12\x13\n\x0bsiteLimYMax\x18\x10 \x02(\x01\x12\x13\n\x0bsiteLimZMin\x18\x11 \x02(\x01\x12\x13\n\x0bsiteLimZMax\x18\x12 \x02(\x01\x12\x13\n\x0bsiteCtrTcsX\x18\x13 \x02(\x01\x12\x13\n\x0bsiteCtrTcsY\x18\x14 \x02(\x01\x12\x13\n\x0bsiteCtrTcsZ\x18\x15 \x02(\x01\x12\x13\n\x0bsensorUnits\x18\x16 \x02(\t\x12\x0e\n\x06\x61\x62sIdx\x18\x17 \x02(\x05\x12\x14\n\x0cisAudioRight\x18\x18 \x02(\x08\x12\x12\n\nsysChanIdx\x18\x19 \x02(\x05\x12\x17\n\x0fsiteAreaMicron2\x18\x1a \x01(\x01\x12\x11\n\tscsToTcsX\x18\x1b \x01(\x01\x12\x11\n\tscsToTcsY\x18\x1c \x01(\x01\x12\x11\n\tscsToTcsZ\x18\x1d \x01(\x01\x12\x10\n\x08sensorID\x18\x1e \x01(\t\x12\x0f\n\x07probeID\x18\x1f \x01(\t\x12\x13\n\x0bheadstageID\x18  \x01(\t\x12\x13\n\x0b\x64\x61tasetRidx\x18! \x01(\x05\x12\x13\n\x0b\x64\x61tasetAidx\x18\" \x01(\x05\x12\x13\n\x0bntvChanName\x18# \x01(\t\x12\x11\n\tsensorUID\x18$ \x01(\t\x12\x11\n\tsensorIdx\x18% \x01(\x05\"\x1f\n\x07XYCoord\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\"+\n\x08XYZCoord\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\"\x81\x03\n\x06Sensor\x12\x0f\n\x07probeId\x18\x01 \x02(\t\x12\x13\n\x0bheadstageId\x18\x02 \x02(\t\x12+\n\twireframe\x18\x03 \x02(\x0b\x32\x18.allego.Sensor.WireFrame\x12\x0c\n\x04xMin\x18\x04 \x02(\x01\x12\x0c\n\x04xMax\x18\x05 \x02(\x01\x12\x0c\n\x04yMin\x18\x06 \x02(\x01\x12\x0c\n\x04yMax\x18\x07 \x02(\x01\x12+\n\x08position\x18\x08 \x02(\x0b\x32\x19.allego.SensorPositionTcs\x12\x11\n\tsensorUID\x18\t \x01(\t\x12\x18\n\x10\x63onnectionNtvIdx\x18\n \x01(\x05\x12\x10\n\x08numSites\x18\x0b \x02(\x05\x12\x11\n\tsensorIdx\x18\x0c \x01(\x05\x1am\n\tWireFrame\x12\x1c\n\x03vtx\x18\x01 \x03(\x0b\x32\x0f.allego.XYCoord\x12 \n\x07vtxXlim\x18\x02 \x02(\x0b\x32\x0f.allego.XYCoord\x12 \n\x07vtxYlim\x18\x03 \x02(\x0b\x32\x0f.allego.XYCoord\"\x98\x02\n\x0eSensorPortSpec\x12\x1f\n\x07sensorA\x18\x01 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorB\x18\x02 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorC\x18\x03 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorD\x18\x04 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorE\x18\x05 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorF\x18\x06 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorG\x18\x07 \x03(\x0b\x32\x0e.allego.Sensor\x12\x1f\n\x07sensorH\x18\x08 \x03(\x0b\x32\x0e.allego.Sensor\"t\n\x10SignalGroupUnits\x12\x32\n\x05units\x18\x01 \x03(\x0b\x32#.allego.SignalGroupUnits.UnitsEntry\x1a,\n\nUnitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x80\x02\n\x0bSignalGroup\x12\'\n\x08\x63hannels\x18\x01 \x03(\x0b\x32\x15.allego.ChannelRecord\x12.\n\x0esensorPortSpec\x18\x02 \x02(\x0b\x32\x16.allego.SensorPortSpec\x12\x12\n\ndatasetUID\x18\x03 \x01(\t\x12\x10\n\x08sampFreq\x18\x04 \x01(\x01\x12\x13\n\x0bsourceLabel\x18\x05 \x01(\t\x12\x19\n\x11neighborMaxRadius\x18\x06 \x01(\x01\x12-\n\x0bsignalUnits\x18\x07 \x01(\x0b\x32\x18.allego.SignalGroupUnits\x12\x13\n\x0bhasDiscrete\x18\x08 \x01(\x08\"\x87\x01\n\x18\x43reateSignalGroupRequest\x12\x16\n\x0e\x64\x61taSourceName\x18\x01 \x02(\t\x12\x16\n\x0e\x64\x61taSourcePath\x18\x02 \x02(\t\x12$\n\x04type\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x15\n\rstreamGroupId\x18\x04 \x02(\t\"s\n\tSubOpSort\x12)\n\x04sort\x18\x01 \x03(\x0e\x32\x1b.allego.SubOpSort.SortField\";\n\tSortField\x12\x0e\n\nSITE_CTR_X\x10\x00\x12\x0e\n\nSITE_CTR_Y\x10\x01\x12\x0e\n\nSITE_CTR_Z\x10\x02\"\xa5\x03\n\x18UpdateSignalGroupRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12=\n\toperation\x18\x02 \x02(\x0e\x32*.allego.UpdateSignalGroupRequest.Operation\x12\x42\n\taddRemove\x18\x03 \x01(\x0e\x32-.allego.UpdateSignalGroupRequest.SubOperationH\x00\x12#\n\x06sortOp\x18\x04 \x01(\x0b\x32\x11.allego.SubOpSortH\x00\x12\x16\n\nntvChanIdx\x18\x05 \x03(\x05\x42\x02\x10\x01\x12&\n\nsignalType\x18\x06 \x02(\x0e\x32\x12.allego.SignalType\x12\x11\n\tpropagate\x18\x07 \x01(\x08\"B\n\tOperation\x12\t\n\x05\x43OLOR\x10\x00\x12\n\n\x06SELECT\x10\x01\x12\x14\n\x10\x44\x45PRECATED_AUDIO\x10\x02\x12\x08\n\x04SORT\x10\x03\"#\n\x0cSubOperation\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06REMOVE\x10\x01\x42\x0e\n\x0csubOperation\"T\n\x14SliceSignalGroupSpec\x12\x0e\n\x06sortBy\x18\x01 \x02(\t\x12\r\n\x05\x64\x65lim\x18\x02 \x02(\t\x12\x1d\n\x02tR\x18\x03 \x01(\x0b\x32\x11.allego.TimeRange\"X\n\x17SliceSignalGroupRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12*\n\x04spec\x18\x02 \x02(\x0b\x32\x1c.allego.SliceSignalGroupSpec\"\x88\x01\n\x15SliceSignalGroupReply\x12\x11\n\tdsourceID\x18\x01 \x01(\t\x12*\n\x04spec\x18\x02 \x02(\x0b\x32\x1c.allego.SliceSignalGroupSpec\x12\x1f\n\x02sG\x18\x03 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x0f\n\x07outcome\x18\x04 \x02(\t\"\x0f\n\rLicenseStatus\"u\n\x12SetDSPGroupRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\"\n\x05stage\x18\x02 \x02(\x0e\x32\x13.allego.FilterStage\x12$\n\tdspParams\x18\x03 \x03(\x0b\x32\x11.allego.DSPParams\"\xf2\x02\n\tDSPParams\x12\x1d\n\x04type\x18\x01 \x02(\x0e\x32\x0f.allego.DSPType\x12\"\n\x05stage\x18\x02 \x02(\x0e\x32\x13.allego.FilterStage\x12\x0e\n\x04\x66req\x18\x03 \x01(\x01H\x00\x12\x36\n\x0c\x66reqSpecBand\x18\x04 \x01(\x0b\x32\x1e.allego.DSPParams.FreqSpecBandH\x00\x12\x17\n\rrefNtvChanIdx\x18\x08 \x01(\x05H\x00\x12\x16\n\x0enotchBandwidth\x18\x05 \x01(\x01\x12\x11\n\tuserLabel\x18\x06 \x02(\t\x12\x1a\n\x04port\x18\x07 \x02(\x0e\x32\x0c.allego.Port\x12\x18\n\x10targetNtvChanIdx\x18\t \x01(\x01\x12\r\n\x05isAux\x18\n \x02(\x08\x12\x12\n\nauxChanIdx\x18\x0b \x01(\x05\x1a\x31\n\x0c\x46reqSpecBand\x12\x0f\n\x07lowFreq\x18\x01 \x02(\x01\x12\x10\n\x08highFreq\x18\x02 \x02(\x01\x42\n\n\x08\x66reqSpec\"\x85\x01\n\x08\x44SPGroup\x12#\n\x08hardware\x18\x01 \x03(\x0b\x32\x11.allego.DSPParams\x12)\n\x0esoftwareStage1\x18\x02 \x03(\x0b\x32\x11.allego.DSPParams\x12)\n\x0esoftwareStage2\x18\x03 \x03(\x0b\x32\x11.allego.DSPParams\"\x9a\x01\n\x10SetSensorRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12\x0f\n\x07probeId\x18\x03 \x01(\t\x12\x13\n\x0bheadstageId\x18\x04 \x01(\t\x12\x18\n\x10\x63onnectionNtvIdx\x18\x05 \x01(\x05\x12\x13\n\x0bnumChannels\x18\x06 \x01(\x05\"m\n\x11SensorPositionTcs\x12\t\n\x01X\x18\x02 \x02(\x01\x12\t\n\x01Y\x18\x03 \x02(\x01\x12\t\n\x01Z\x18\x04 \x02(\x01\x12\x11\n\tRingAngle\x18\x05 \x02(\x01\x12\x12\n\nAxialAngle\x18\x06 \x02(\x01\x12\x10\n\x08\x41rcAngle\x18\x07 \x02(\x01\"\x90\x01\n\x1bSetSensorPositionTcsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12+\n\x08position\x18\x03 \x02(\x0b\x32\x19.allego.SensorPositionTcs\x12\x11\n\tsensorIdx\x18\x04 \x01(\x05\"F\n\x0fSitePositionTcs\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\t\n\x01X\x18\x02 \x02(\x01\x12\t\n\x01Y\x18\x03 \x02(\x01\x12\t\n\x01Z\x18\x04 \x02(\x01\"\x7f\n\x1aSetSitePositionsTcsRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12.\n\rsitePositions\x18\x03 \x03(\x0b\x32\x17.allego.SitePositionTcs\"Y\n\x17\x46\x65\x61tureStartStopRequest\x12\x0e\n\x06nodeId\x18\x01 \x02(\t\x12.\n\x0e\x66\x65\x61tureLicense\x18\x02 \x02(\x0e\x32\x16.allego.FeatureLicense\"!\n\x0cPrivacyReply\x12\x11\n\tisPrivate\x18\x02 \x02(\x08\"&\n\x11SetPrivacyRequest\x12\x11\n\tisPrivate\x18\x01 \x02(\x08\"7\n\x0b\x44\x65nseMatrix\x12\x0c\n\x04rows\x18\x01 \x02(\x03\x12\x0c\n\x04\x63ols\x18\x02 \x02(\x03\x12\x0c\n\x04\x64\x61ta\x18\x03 \x02(\x0c\"\\\n\tHistogram\x12\r\n\x05stats\x18\x01 \x03(\x01\x12\x0e\n\x06\x63ounts\x18\x02 \x03(\x01\x12\x10\n\x08\x64ividers\x18\x03 \x03(\x01\x12\x0f\n\x07numBins\x18\x04 \x02(\x03\x12\r\n\x05isPDF\x18\x05 \x02(\x08\"Y\n\x0bKpiMetricID\x12$\n\x04mode\x18\x01 \x02(\x0e\x32\x16.allego.KpiMetricsMode\x12$\n\x04name\x18\x02 \x02(\x0e\x32\x16.allego.KpiMetricsEnum\"\x85\x01\n\tTimeRange\x12\x14\n\x0ctimeRangeSec\x18\x01 \x03(\x01\x12\x11\n\ttimestamp\x18\x02 \x03(\x03\x12\n\n\x02\x66s\x18\x03 \x02(\x01\x12\x15\n\rwallTimeStart\x18\x04 \x01(\t\x12,\n\x08wallTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"q\n\tBundleReq\x12\x0f\n\x07ntvIdxs\x18\x01 \x03(\x05\x12\x1d\n\x02tR\x18\x02 \x02(\x0b\x32\x11.allego.TimeRange\x12$\n\x07metrics\x18\x04 \x03(\x0b\x32\x13.allego.KpiMetricID\x12\x0e\n\x06isTail\x18\x05 \x02(\x08\"\x9d\x01\n\rKpiMetricsReq\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12!\n\x05stype\x18\x02 \x01(\x0e\x32\x12.allego.SignalType\x12\x1e\n\x03\x61rg\x18\x03 \x02(\x0b\x32\x11.allego.BundleReq\x12\x0e\n\x06isPlot\x18\x04 \x01(\x08\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x14\n\x0cisReturnData\x18\x06 \x01(\x08\"\x83\x03\n\x0eKpiMetricsData\x12\x12\n\nnumPackets\x18\x01 \x02(\x03\x12\x0f\n\x07numSigs\x18\x02 \x02(\x03\x12\x12\n\nnumMetrics\x18\x03 \x02(\x03\x12#\n\x06metric\x18\x04 \x03(\x0b\x32\x13.allego.KpiMetricID\x12\x0f\n\x07pktIdxs\x18\x05 \x03(\x03\x12 \n\x03val\x18\x06 \x02(\x0b\x32\x13.allego.DenseMatrix\x12\x35\n\tstatsPkts\x18\x07 \x02(\x0b\x32\".allego.KpiMetricsData.MetricStats\x12\x31\n\x05stats\x18\x08 \x02(\x0b\x32\".allego.KpiMetricsData.MetricStats\x12\x14\n\x0cpacketDurSec\x18\t \x02(\x01\x12\x1d\n\x02tR\x18\n \x02(\x0b\x32\x11.allego.TimeRange\x1a\x41\n\x0bMetricStats\x12\x0c\n\x04mean\x18\x01 \x03(\x01\x12\n\n\x02sD\x18\x02 \x03(\x01\x12\x0b\n\x03max\x18\x03 \x03(\x01\x12\x0b\n\x03min\x18\x04 \x03(\x01\"w\n\x16KpiBundlePacketMetrics\x12\x0f\n\x07ntvIdxs\x18\x01 \x03(\x05\x12#\n\x07sigType\x18\x02 \x02(\x0e\x32\x12.allego.SignalType\x12\'\n\x07metrics\x18\x04 \x02(\x0b\x32\x16.allego.KpiMetricsData\"S\n\nKpiMetrics\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12.\n\x06\x62undle\x18\x02 \x02(\x0b\x32\x1e.allego.KpiBundlePacketMetrics\"c\n\x11KpiControlRequest\x12\x15\n\rstreamGroupId\x18\x01 \x02(\t\x12!\n\x05stype\x18\x02 \x01(\x0e\x32\x12.allego.SignalType\x12\x14\n\x0cisAllBundles\x18\x03 \x01(\x08\":\n\x12SetKpiParamRequest\x12\x15\n\rstreamGroupId\x18\x01 \x01(\t\x12\r\n\x05param\x18\x02 \x01(\x01\",\n\x13GetKpiStatusRequest\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\"K\n\x12KpiStandardRequest\x12\x11\n\tdsourceID\x18\x02 \x03(\t\x12\"\n\x03\x63md\x18\x03 \x01(\x0e\x32\x15.allego.KpiScannerCmd\"\xba\x01\n\rKpiFileStatus\x12,\n\x07\x64source\x18\x01 \x03(\x0b\x32\x1b.allego.KpiFileStatus.State\x1a{\n\x05State\x12\x0f\n\x07isAvail\x18\x01 \x02(\x08\x12\x12\n\nisComplete\x18\x02 \x01(\x08\x12\x12\n\ndsourceUID\x18\x03 \x01(\t\x12 \n\x05kpiTR\x18\x04 \x01(\x0b\x32\x11.allego.TimeRange\x12\x17\n\x0f\x66ilePathAndName\x18\x05 \x01(\t\"\xc7\x04\n\x0eKpiFileStatus2\x12>\n\x07\x64source\x18\x01 \x03(\x0b\x32-.allego.KpiFileStatus2.KpiDatasourceStateSpec\x1a\xe9\x01\n\tKPI_State\x12\x0f\n\x07isAvail\x18\x01 \x02(\x08\x12\x12\n\nisComplete\x18\x02 \x01(\x08\x12\x14\n\x0c\x66racComplete\x18\x03 \x01(\x01\x12\x17\n\x0f\x66ilePathAndName\x18\x04 \x01(\t\x12 \n\x05kpiTR\x18\x05 \x01(\x0b\x32\x11.allego.TimeRange\x12\x14\n\x0cpacketDurSec\x18\x06 \x01(\x01\x12\x0e\n\x06numAmp\x18\x07 \x01(\x03\x12\x18\n\x10\x62ytesInBundlePkt\x18\x08 \x01(\x03\x12\x12\n\nnumPackets\x18\t \x01(\x03\x12\x12\n\ndatasetUID\x18\n \x01(\t\x1aq\n\x10\x44\x61tasource_State\x12\x17\n\x0f\x66ilePathAndName\x18\x01 \x01(\t\x12\x1d\n\x02TR\x18\x02 \x01(\x0b\x32\x11.allego.TimeRange\x12\x12\n\ndatasetUID\x18\x03 \x01(\t\x12\x11\n\tdsourceID\x18\x04 \x01(\t\x1a\x95\x01\n\x16KpiDatasourceStateSpec\x12\x37\n\x06source\x18\x01 \x02(\x0b\x32\'.allego.KpiFileStatus2.Datasource_State\x12-\n\x03kpi\x18\x02 \x02(\x0b\x32 .allego.KpiFileStatus2.KPI_State\x12\x13\n\x0bisSprinting\x18\x03 \x02(\x08\"\xfd\x01\n\x0fKpiFileMetadata\x12.\n\x07\x64source\x18\x01 \x03(\x0b\x32\x1d.allego.KpiFileMetadata.State\x1a\xb9\x01\n\x05State\x12\x0f\n\x07isAvail\x18\x01 \x02(\x08\x12\x12\n\ndsourceUID\x18\x02 \x01(\t\x12\x11\n\tpacketDur\x18\x03 \x01(\x01\x12\x0c\n\x04nAMP\x18\x04 \x01(\x03\x12\x1b\n\x13\x62ytesInBundlePacket\x18\x05 \x01(\x03\x12\x12\n\nnumPackets\x18\x06 \x01(\x03\x12 \n\x05kpiTR\x18\x07 \x01(\x0b\x32\x11.allego.TimeRange\x12\x17\n\x0f\x66ilePathAndName\x18\x08 \x01(\t\"\xd3\x02\n\x0eKpiStatusReply\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\x12\x11\n\ttimeRange\x18\x03 \x01(\x01\x12\x16\n\x0etimestampRange\x18\x04 \x01(\x03\x12\x18\n\x10numPacketsMemory\x18\x05 \x02(\x03\x12\x11\n\tpacketDur\x18\x06 \x02(\x01\x12\x14\n\x0cupdatePeriod\x18\x07 \x02(\x01\x12\x13\n\x0bpersistence\x18\x08 \x02(\x01\x12\x0c\n\x04\x62\x65ta\x18\t \x02(\x01\x12\x1d\n\x15isTrackingSignalCache\x18\x0b \x02(\x08\x12\x12\n\nnumPackets\x18\x0c \x02(\x03\x12\x13\n\x0bmemoryBytes\x18\r \x02(\x01\x12\n\n\x02\x66s\x18\x0e \x01(\x01\x12\x15\n\rwallTimeStart\x18\x0f \x01(\t\x12\x1d\n\x02tR\x18\x10 \x01(\x0b\x32\x11.allego.TimeRange\x12\x0f\n\x07numSigs\x18\x11 \x01(\x03\"\xe6\x02\n\x11SigKpiParamRecord\x12\x15\n\risEventDetect\x18\x01 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x02 \x02(\x05\x12\x11\n\teventThr0\x18\x03 \x02(\x01\x12\x11\n\teventThr1\x18\x04 \x02(\x01\x12\x13\n\x0b\x65ventThrSd0\x18\x05 \x02(\x01\x12\x13\n\x0b\x65ventThrSd1\x18\x06 \x02(\x01\x12\x11\n\tpreThrPts\x18\x07 \x02(\x05\x12\x12\n\npostThrPts\x18\x08 \x02(\x05\x12\x11\n\tevtDurPts\x18\t \x02(\x05\x12\x11\n\tshadowPts\x18\n \x02(\x05\x12\x0e\n\x06preThr\x18\x0b \x02(\x01\x12\x0f\n\x07postThr\x18\x0c \x02(\x01\x12\x0e\n\x06\x65vtDur\x18\r \x02(\x01\x12\x0e\n\x06shadow\x18\x0e \x02(\x01\x12\x11\n\tisSetThr0\x18\x0f \x02(\x08\x12\x11\n\tisSetThr1\x18\x10 \x02(\x08\x12\x10\n\x08isSDThr0\x18\x11 \x02(\x08\x12\x10\n\x08isSDThr1\x18\x12 \x02(\x08\"J\n\x0e\x41nnotateBundle\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\r\n\x05notes\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x01(\t\"]\n\x0fProjectMetadata\x12\x12\n\nprojectUID\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61seUID\x18\x02 \x01(\t\x12\x10\n\x08trialUID\x18\x03 \x01(\t\x12\x13\n\x0b\x61nnotateUID\x18\x04 \x03(\t\"3\n\x16SensorExtendedMetadata\x12\x19\n\x11sensorInstanceUID\x18\x01 \x01(\t\"%\n\x0fGonumMatrixList\x12\x12\n\nmdataBytes\x18\x01 \x02(\x0c\"6\n\x0fRadixMatrixList\x12#\n\x06matrix\x18\x01 \x03(\x0b\x32\x13.allego.RadixMatrix\"*\n\x0bRadixMatrix\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x02\x12\r\n\x05shape\x18\x02 \x03(\x05\"/\n\x10RadixMatrixBytes\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\x12\r\n\x05shape\x18\x02 \x03(\x05\"8\n\x10RadixSignalsList\x12$\n\x06matrix\x18\x01 \x03(\x0b\x32\x14.allego.RadixSignals\"\xa9\x01\n\x0cRadixSignals\x12\x10\n\x08sampFreq\x18\x01 \x02(\x01\x12 \n\x03pri\x18\x02 \x02(\x0b\x32\x13.allego.RadixMatrix\x12 \n\x03\x61ux\x18\x03 \x02(\x0b\x32\x13.allego.RadixMatrix\x12 \n\x03\x64in\x18\x04 \x02(\x0b\x32\x13.allego.RadixMatrix\x12!\n\x04\x64out\x18\x05 \x02(\x0b\x32\x13.allego.RadixMatrix\"\x19\n\x0cVectorString\x12\t\n\x01x\x18\x01 \x03(\t\"\x1a\n\rVectorFloat64\x12\t\n\x01x\x18\x01 \x03(\x01\"G\n\x12VectorSliceFloat64\x12\"\n\x03vec\x18\x01 \x03(\x0b\x32\x15.allego.VectorFloat64\x12\r\n\x05label\x18\x02 \x01(\t\"\xde\x02\n\x14LogsysKpiStatusReply\x12\x1f\n\x05portA\x18\x01 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portB\x18\x02 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portC\x18\x03 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portD\x18\x04 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portE\x18\x05 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portF\x18\x06 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portG\x18\x07 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1f\n\x05portH\x18\x08 \x02(\x0b\x32\x10.allego.KpiCache\x12\x1e\n\x04\x61ux0\x18\t \x02(\x0b\x32\x10.allego.KpiCache\x12\x1e\n\x04\x61ux1\x18\n \x02(\x0b\x32\x10.allego.KpiCache\"\xfc\x02\n\x08KpiCache\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x12\n\npersistDur\x18\x03 \x02(\x01\x12\x15\n\rminNumPackets\x18\x04 \x02(\x05\x12\x11\n\tsizeBytes\x18\x05 \x02(\x05\x12\x12\n\nnumPackets\x18\x06 \x02(\x05\x12\x0e\n\x06tRange\x18\x07 \x03(\x01\x12\x0f\n\x07tsRange\x18\x08 \x03(\x03\x12\x15\n\rmeanPacketDur\x18\t \x02(\x01\x12\x19\n\x11meanCalcPacketDur\x18\n \x02(\x01\x12\x11\n\tpacketDur\x18\x0b \x02(\x01\x12\x1d\n\x15totalPacketsProcessed\x18\x0c \x02(\r\x12\x12\n\nsignalType\x18\r \x02(\t\x12\x12\n\nnumPriSigs\x18\x0e \x02(\x05\x12\x12\n\nnumAuxSigs\x18\x0f \x02(\x05\x12\x12\n\nnumDinSigs\x18\x10 \x02(\x05\x12\x13\n\x0bnumDoutSigs\x18\x11 \x02(\x05\x12\x14\n\x0cupdatePeriod\x18\x12 \x02(\x01\"\xfa\x02\n\x12LogsysKpiTailReply\x12\"\n\x05portA\x18\x01 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portB\x18\x02 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portC\x18\x03 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portD\x18\x04 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portE\x18\x05 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portF\x18\x06 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portG\x18\x07 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12\"\n\x05portH\x18\x08 \x01(\x0b\x32\x13.allego.KpiPortInfo\x12!\n\x04\x61ux0\x18\t \x01(\x0b\x32\x13.allego.KpiPortInfo\x12!\n\x04\x61ux1\x18\n \x01(\x0b\x32\x13.allego.KpiPortInfo\"3\n\x0bKpiPortInfo\x12$\n\x07kpiTail\x18\x01 \x03(\x0b\x32\x13.allego.KpiTailRows\"\xf4\x02\n\x0bKpiTailRows\x12\x10\n\x08wallTime\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x02(\x01\x12\x14\n\x0clocalSigType\x18\x03 \x02(\t\x12\x12\n\nntvChanIdx\x18\x04 \x02(\x03\x12\x0b\n\x03\x64ur\x18\x05 \x02(\x01\x12\x0e\n\x06stdDev\x18\x06 \x02(\x01\x12\x0f\n\x07\x63StdDev\x18\x07 \x02(\x01\x12\x11\n\tabsEvtAmp\x18\x08 \x02(\x01\x12\x12\n\ncabsEvtAmp\x18\t \x02(\x01\x12\x0b\n\x03SNR\x18\n \x02(\x01\x12\x0c\n\x04\x63SNR\x18\x0b \x02(\x01\x12\x0f\n\x07numEvts\x18\x0c \x02(\x05\x12\x10\n\x08\x63numEvts\x18\r \x02(\x05\x12\x0f\n\x07\x65vtRate\x18\x0e \x02(\x01\x12\x10\n\x08\x63\x45vtRate\x18\x0f \x02(\x01\x12\x0b\n\x03max\x18\x10 \x02(\x01\x12\x0c\n\x04\x63max\x18\x11 \x02(\x01\x12\x0b\n\x03min\x18\x12 \x02(\x01\x12\x0c\n\x04\x63min\x18\x13 \x02(\x01\x12\x14\n\x0cmeanPosPkAmp\x18\x14 \x02(\x01\x12\x14\n\x0cmeanNegPkAmp\x18\x15 \x02(\x01\"*\n\x18WarehouseHealthcheckSpec\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\"(\n\x19OutfitterGetDeviceRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x9e\x01\n\x11SensorCompRequest\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageDesc\x12\x16\n\x0eisIncludeModel\x18\x03 \x01(\x08\x12\x19\n\x11isIncludeMetadata\x18\x04 \x01(\x08\x12\n\n\x02iD\x18\x05 \x01(\t\"z\n\x19RegisterSensorCompRequest\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageDesc\x12\x11\n\tprofileID\x18\x03 \x02(\t\"\x92\x01\n\x1dSaveSensorCompInstanceRequest\x12 \n\x05probe\x18\x01 \x01(\x0b\x32\x11.allego.ProbeDesc\x12(\n\theadstage\x18\x02 \x01(\x0b\x32\x15.allego.HeadstageDesc\x12\x19\n\x11isIncludeMetadata\x18\x04 \x01(\x08\x12\n\n\x02iD\x18\x05 \x01(\t\"&\n\tProbeDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03uID\x18\x02 \x01(\t\"*\n\rHeadstageDesc\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03uID\x18\x02 \x01(\t\"`\n\x12GetSensorCompReply\x12 \n\x05probe\x18\x01 \x03(\x0b\x32\x11.allego.ProbeSpec\x12(\n\theadstage\x18\x02 \x03(\x0b\x32\x15.allego.HeadstageSpec\"x\n\tProbeSpec\x12\x1f\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x11.allego.ProbeDesc\x12!\n\x05model\x18\x02 \x01(\x0b\x32\x12.allego.ProbeModel\x12\'\n\x08metaData\x18\x03 \x01(\x0b\x32\x15.allego.ProbeMetaData\"\x88\x01\n\rHeadstageSpec\x12#\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x15.allego.HeadstageDesc\x12%\n\x05model\x18\x02 \x01(\x0b\x32\x16.allego.HeadstageModel\x12+\n\x08metaData\x18\x03 \x01(\x0b\x32\x19.allego.HeadstageMetaData\"\xce\x04\n\nProbeModel\x12\n\n\x02iD\x18\x01 \x02(\t\x12.\n\x04site\x18\x02 \x03(\x0b\x32 .allego.ProbeModel.ProbeSiteDesc\x12\x34\n\twireframe\x18\x03 \x02(\x0b\x32!.allego.ProbeModel.ProbeWireFrame\x12\x34\n\x0esiteOverallMin\x18\x05 \x02(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x12\x34\n\x0esiteOverallMax\x18\x06 \x02(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x1a\xde\x01\n\rProbeSiteDesc\x12\x0c\n\x04\x61rea\x18\x01 \x02(\x01\x12\x0f\n\x07\x63\x65nterX\x18\x02 \x02(\x01\x12\x0f\n\x07\x63\x65nterY\x18\x03 \x02(\x01\x12\x0f\n\x07\x63\x65nterZ\x18\x04 \x02(\x01\x12\x11\n\tlimitXMax\x18\x05 \x02(\x01\x12\x11\n\tlimitXMin\x18\x06 \x02(\x01\x12\x11\n\tlimitYMax\x18\x07 \x02(\x01\x12\x11\n\tlimitYMin\x18\x08 \x02(\x01\x12\x11\n\tlimitZMax\x18\t \x02(\x01\x12\x11\n\tlimitZMin\x18\n \x02(\x01\x12\x0b\n\x03num\x18\x0b \x02(\x03\x12\r\n\x05shape\x18\x0c \x02(\t\x1a^\n\x0eProbeWireFrame\x12,\n\x06vertex\x18\x01 \x03(\x0b\x32\x1c.allego.ProbeModel.ProbePtXY\x12\x0e\n\x06limitX\x18\x02 \x03(\x01\x12\x0e\n\x06limitY\x18\x03 \x03(\x01\x1a!\n\tProbePtXY\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\"_\n\rProbeMetaData\x12\x11\n\tprobeName\x18\x01 \x02(\t\x12\x10\n\x08numSites\x18\x02 \x02(\x05\x12\x13\n\x0b\x63\x61talogTags\x18\x03 \x02(\t\x12\x14\n\x0cinstanceTags\x18\x04 \x02(\t\"\x84\x01\n\x0eHeadstageModel\x12\n\n\x02iD\x18\x01 \x02(\t\x12\x31\n\x04rows\x18\x02 \x03(\x0b\x32#.allego.HeadstageModel.HeadstageRow\x1a\x33\n\x0cHeadstageRow\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x03\x12\x0f\n\x07siteNum\x18\x02 \x02(\x03\"\x13\n\x11HeadstageMetaData\"5\n\x0bUserProfile\x12\x11\n\tprofileID\x18\x01 \x02(\t\x12\x13\n\x0blicenseCode\x18\x02 \x02(\t\"B\n\x16GetCurrentProfileReply\x12(\n\x0buserProfile\x18\x01 \x02(\x0b\x32\x13.allego.UserProfile\"@\n\x13GetAllProfilesReply\x12)\n\x0cuserProfiles\x18\x01 \x03(\x0b\x32\x13.allego.UserProfile\"-\n\x18SetCurrentProfileRequest\x12\x11\n\tprofileID\x18\x01 \x02(\t\"\x88\x01\n\x14ManageNodeOrgPayload\x12\r\n\x05orgID\x18\x01 \x01(\t\x12\x0f\n\x07orgName\x18\x02 \x01(\t\x12\x14\n\x0corgShortName\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x01(\t\"i\n\x14ManageNodeOrgRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12-\n\x07payload\x18\x02 \x03(\x0b\x32\x1c.allego.ManageNodeOrgPayload\"S\n\x12ManageNodeOrgReply\x12-\n\x07payload\x18\x01 \x03(\x0b\x32\x1c.allego.ManageNodeOrgPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"\xa2\x01\n\x14ManageNodeLabPayload\x12\r\n\x05labID\x18\x01 \x01(\t\x12\x0f\n\x07labDesc\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65pt\x18\x03 \x01(\t\x12\x14\n\x0corganization\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x64minID\x18\x05 \x01(\t\x12\x11\n\tlabHeadID\x18\x06 \x01(\t\x12\x14\n\x0clabManagerID\x18\x07 \x01(\t\x12\x0c\n\x04tags\x18\x08 \x01(\t\"i\n\x14ManageNodeLabRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12-\n\x07payload\x18\x02 \x03(\x0b\x32\x1c.allego.ManageNodeLabPayload\"S\n\x12ManageNodeLabReply\x12-\n\x07payload\x18\x01 \x03(\x0b\x32\x1c.allego.ManageNodeLabPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"\x99\x01\n\x15ManageNodeUserPayload\x12\x0e\n\x06userID\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\x0c\x12\"\n\x04role\x18\x04 \x01(\x0e\x32\x14.allego.UserRoleType\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x0f\n\x07labName\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x01(\t\"k\n\x15ManageNodeUserRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12.\n\x07payload\x18\x02 \x03(\x0b\x32\x1d.allego.ManageNodeUserPayload\"U\n\x13ManageNodeUserReply\x12.\n\x07payload\x18\x01 \x03(\x0b\x32\x1d.allego.ManageNodeUserPayload\x12\x0e\n\x06\x65rrMsg\x18\x02 \x01(\t\"6\n\x13\x43\x61talogProbePayload\x12\x1f\n\x04spec\x18\x01 \x02(\x0b\x32\x11.allego.ProbeSpec\"]\n\x10ProbeNodeRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.ManageNodeCmd\x12%\n\x07payload\x18\x02 \x03(\x0b\x32\x14.allego.ProbePayload\"7\n\x0eProbeNodeReply\x12%\n\x07payload\x18\x01 \x03(\x0b\x32\x14.allego.ProbePayload\"/\n\x0cProbePayload\x12\x1f\n\x04spec\x18\x01 \x02(\x0b\x32\x11.allego.ProbeSpec\"\xa5\x02\n\x0b\x45\x64gePayload\x12/\n\x06source\x18\x01 \x02(\x0b\x32\x1f.allego.EdgePayload.GenericNode\x12/\n\x06target\x18\x02 \x02(\x0b\x32\x1f.allego.EdgePayload.GenericNode\x12)\n\tedgeLabel\x18\x03 \x02(\x0e\x32\x16.allego.WorldEdgeLabel\x12-\n\tdirection\x18\x04 \x02(\x0e\x32\x1a.allego.WorldEdgeDirection\x1aZ\n\x0bGenericNode\x12%\n\x05label\x18\x01 \x02(\x0e\x32\x16.allego.WorldNodeLabel\x12\x11\n\tidPropKey\x18\x02 \x02(\t\x12\x11\n\tidPropVal\x18\x03 \x02(\t\"8\n\x10WorldEdgeRequest\x12$\n\x07payload\x18\x01 \x03(\x0b\x32\x13.allego.EdgePayload\"\x10\n\x0eWorldEdgeReply\"E\n\x11QueryWorldRequest\x12\"\n\x03\x63md\x18\x01 \x02(\x0e\x32\x15.allego.WorldQueryCmd\x12\x0c\n\x04\x61rgs\x18\x02 \x03(\t\"\xe6\x01\n\rQueryWorldRec\x12)\n\x03org\x18\x01 \x01(\x0b\x32\x1c.allego.ManageNodeOrgPayload\x12)\n\x03lab\x18\x02 \x01(\x0b\x32\x1c.allego.ManageNodeLabPayload\x12+\n\x04user\x18\x03 \x01(\x0b\x32\x1d.allego.ManageNodeUserPayload\x12-\n\x08\x63\x61tProbe\x18\x04 \x01(\x0b\x32\x1b.allego.CatalogProbePayload\x12#\n\x05probe\x18\x05 \x01(\x0b\x32\x14.allego.ProbePayload\"9\n\x0fQueryWorldReply\x12&\n\x07payload\x18\x01 \x03(\x0b\x32\x15.allego.QueryWorldRec\"/\n\x1aHighLowPassTransformParams\x12\x11\n\tfrequency\x18\x01 \x02(\x01\"B\n\x13\x42\x61ndTransformParams\x12\x14\n\x0clowFrequency\x18\x01 \x02(\x01\x12\x15\n\rhighFrequency\x18\x02 \x02(\x01\"F\n\x14NotchTransformParams\x12\x16\n\x0enotchFrequency\x18\x01 \x02(\x01\x12\x16\n\x0enotchBandwidth\x18\x02 \x02(\x01\"\x14\n\x12\x43\x41RTransformParams\"2\n\x19VirtualRefTransformParams\x12\x15\n\rrefNtvChanIdx\x18\x01 \x02(\x05\"K\n\x18PairedRefTransformParams\x12\x15\n\rrefNtvChanIdx\x18\x01 \x02(\x05\x12\x18\n\x10targetNtvChanIdx\x18\x02 \x02(\x05\"i\n\x1d\x44\x61taSourceSinkTransformParams\x12\x10\n\x08\x64srcName\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12(\n\x08\x66ileType\x18\x03 \x02(\x0e\x32\x16.allego.RadixFileTypes\">\n\x18SliceTimeTransformParams\x12\x11\n\ttimeStart\x18\x01 \x02(\x01\x12\x0f\n\x07timeEnd\x18\x02 \x02(\x01\"n\n\x1cSliceChannelsTransformParams\x12\x13\n\x0bsysChanIdxs\x18\x01 \x03(\x05\x12(\n\x0bsignalGroup\x18\x02 \x01(\x0b\x32\x13.allego.SignalGroup\x12\x0f\n\x07\x64srcUid\x18\x03 \x01(\t\"1\n\x19\x44ownsampleTransformParams\x12\x14\n\x0csampleFactor\x18\x01 \x02(\x05\"\xdb\x01\n\x1aRemapSensorTransformParams\x12>\n\x07sensors\x18\x01 \x03(\x0b\x32-.allego.RemapSensorTransformParams.SensorSpec\x1a}\n\nSensorSpec\x12\x1a\n\x04port\x18\x02 \x02(\x0e\x32\x0c.allego.Port\x12\x0f\n\x07probeId\x18\x03 \x02(\t\x12\x13\n\x0bheadstageId\x18\x04 \x02(\t\x12\x18\n\x10\x63onnectionNtvIdx\x18\x05 \x01(\x05\x12\x13\n\x0bnumChannels\x18\x06 \x01(\x05\" \n\x08Position\x12\t\n\x01x\x18\x01 \x02(\x05\x12\t\n\x01y\x18\x02 \x02(\x05\"\x98\x06\n\rTransformNode\x12\n\n\x02id\x18\x01 \x02(\t\x12\'\n\x04type\x18\x02 \x02(\x0e\x32\x19.allego.TransformNodeType\x12\"\n\x08position\x18\x03 \x01(\x0b\x32\x10.allego.Position\x12\x0f\n\x07invalid\x18\x04 \x02(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x05 \x01(\t\x12=\n\x11highLowPassParams\x18\x06 \x01(\x0b\x32\".allego.HighLowPassTransformParams\x12/\n\nbandParams\x18\x07 \x01(\x0b\x32\x1b.allego.BandTransformParams\x12\x31\n\x0bnotchParams\x18\x08 \x01(\x0b\x32\x1c.allego.NotchTransformParams\x12-\n\tcarParams\x18\t \x01(\x0b\x32\x1a.allego.CARTransformParams\x12;\n\x10virtualRefParams\x18\n \x01(\x0b\x32!.allego.VirtualRefTransformParams\x12\x39\n\x0fpairedRefParams\x18\x0b \x01(\x0b\x32 .allego.PairedRefTransformParams\x12\x43\n\x14\x64\x61tasourceSinkParams\x18\x0c \x01(\x0b\x32%.allego.DataSourceSinkTransformParams\x12\x39\n\x0fsliceTimeParams\x18\r \x01(\x0b\x32 .allego.SliceTimeTransformParams\x12\x41\n\x13sliceChannelsParams\x18\x0e \x01(\x0b\x32$.allego.SliceChannelsTransformParams\x12;\n\x10\x64ownsampleParams\x18\x0f \x01(\x0b\x32!.allego.DownsampleTransformParams\x12=\n\x11remapSensorParams\x18\x10 \x01(\x0b\x32\".allego.RemapSensorTransformParams\";\n\rTransformEdge\x12\n\n\x02id\x18\x01 \x02(\t\x12\x0e\n\x06source\x18\x02 \x02(\t\x12\x0e\n\x06target\x18\x03 \x02(\t\"t\n\x08Protocol\x12\n\n\x02id\x18\x01 \x02(\t\x12-\n\x0etransformNodes\x18\x02 \x03(\x0b\x32\x15.allego.TransformNode\x12-\n\x0etransformEdges\x18\x03 \x03(\x0b\x32\x15.allego.TransformEdge\"%\n\x0fProtocolRequest\x12\x12\n\nprotocolID\x18\x01 \x02(\t\"B\n\x15RenameProtocolRequest\x12\x12\n\nprotocolID\x18\x01 \x02(\t\x12\x15\n\rnewProtocolID\x18\x02 \x02(\t\";\n\x14GetAllProtocolsReply\x12#\n\tprotocols\x18\x01 \x03(\x0b\x32\x10.allego.Protocol\"{\n\x15\x41pplyProtocolProgress\x12\x1c\n\x14lastTimestampWritten\x18\x01 \x02(\x05\x12\x18\n\x10\x64srcTimestampEnd\x18\x02 \x02(\x05\x12\x14\n\x0c\x66racComplete\x18\x03 \x01(\x01\x12\x14\n\x0cincrementSec\x18\x04 \x01(\x01\"\x9a\x01\n\x1aSpikeSorterSetParamRequest\x12\x15\n\rspikeSorterID\x18\x01 \x02(\t\x12,\n\x03\x63md\x18\x02 \x02(\x0e\x32\x1f.allego.SpikeSorterParamCommand\x12\x12\n\nregFloat64\x18\x03 \x03(\x01\x12\x0f\n\x07regBool\x18\x05 \x03(\x08\x12\x12\n\nntvChanIdx\x18\x06 \x03(\x05\"Q\n\x1bSpikeSorterSetParamsRequest\x12\x32\n\x06params\x18\x01 \x03(\x0b\x32\".allego.SpikeSorterSetParamRequest\"\xa7\x02\n\x1dSpikeSorterParamCommandRecord\x12\x11\n\tisEnabled\x18\x01 \x02(\x08\x12\x12\n\nntvChanIdx\x18\x02 \x02(\x05\x12\x0b\n\x03thr\x18\x03 \x03(\x01\x12\r\n\x05thrSd\x18\x04 \x03(\x01\x12\x11\n\tthrWdwPts\x18\x05 \x03(\x05\x12\x0e\n\x06thrWdw\x18\x06 \x03(\x01\x12\x0e\n\x06shadow\x18\x07 \x02(\x01\x12\x11\n\tshadowPts\x18\x08 \x02(\x05\x12\x10\n\x08isSetThr\x18\t \x03(\x08\x12\x0f\n\x07weakThr\x18\n \x03(\x01\x12\x11\n\tweakThrSd\x18\x0b \x03(\x01\x12\x14\n\x0cisSetWeakThr\x18\x0c \x03(\x08\x12\x12\n\npeakWdwPts\x18\r \x03(\x05\x12\x0f\n\x07peakWdw\x18\x0e \x03(\x01\x12\x0c\n\x04isSD\x18\x0f \x02(\x08\"?\n\tKpiParams\x12\x32\n\x03rec\x18\x01 \x03(\x0b\x32%.allego.SpikeSorterParamCommandRecord\"J\n\x10\x44\x41\x43StreamRequest\x12\x0b\n\x03\x44\x41\x43\x18\x01 \x02(\x05\x12\x12\n\nNtvChanIdx\x18\x02 \x02(\x05\x12\x15\n\rstreamGroupId\x18\x03 \x01(\t\"\xde\x01\n\x11\x45ventViewerConfig\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\x12\x19\n\x11triggerSysChanIdx\x18\x03 \x01(\x05\x12\x1a\n\x12triggerThresholdUV\x18\x04 \x01(\x01\x12\x14\n\x0cpreTriggerMs\x18\x05 \x02(\x01\x12\x15\n\rpostTriggerMs\x18\x06 \x02(\x01\x12\'\n\x0btriggerType\x18\x07 \x01(\x0e\x32\x12.allego.SignalType\x12\x0e\n\x06ntvIdx\x18\x08 \x01(\x05\"=\n\rEventViewerID\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x15\n\rstreamGroupId\x18\x02 \x02(\t\"D\n\x1aGetEventViewerEventRequest\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12\x0f\n\x07\x65ventId\x18\x02 \x02(\t\"Y\n\x14\x45ventViewerEventDesc\x12\x0f\n\x07\x65ventId\x18\x01 \x02(\t\x12\x18\n\x10triggerTimestamp\x18\x02 \x02(\x03\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\"\x8f\x01\n\x10\x45ventViewerEvent\x12\x0f\n\x07\x65ventId\x18\x01 \x02(\t\x12\x18\n\x10triggerTimestamp\x18\x02 \x02(\x03\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12#\n\x07signals\x18\x04 \x02(\x0b\x32\x12.allego.RawSignals\x12\x13\n\x0bsysChanIdxs\x18\x05 \x03(\x05\"a\n\x1aListEventViewerEventsReply\x12\x15\n\reventViewerId\x18\x01 \x02(\t\x12,\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x1c.allego.EventViewerEventDesc\"D\n\x15ListEventViewersReply\x12+\n\x0c\x65ventViewers\x18\x01 \x03(\x0b\x32\x15.allego.EventViewerID\"3\n\x1fStatusPollFieldsToUpdateRequest\x12\x10\n\x08\x63lientId\x18\x01 \x02(\t\"^\n\x18StatusPollFieldsToUpdate\x12\x10\n\x08\x63lientId\x18\x01 \x02(\t\x12\x30\n\x0e\x66ieldsToUpdate\x18\x02 \x03(\x0e\x32\x18.allego.StatusPollFields\"\xa5\x01\n\x17\x44\x61shboardCommandRequest\x12\'\n\x08\x64\x61shType\x18\x01 \x01(\x0e\x32\x15.allego.DashboardType\x12\x32\n\x04\x61rgs\x18\x02 \x01(\x0b\x32$.allego.DashboardCommandRequest.Args\x1a-\n\x04\x41rgs\x12%\n\x03\x63md\x18\x01 \x02(\x0e\x32\x18.allego.DashboardCommand\"]\n\x13SelTableSignalGroup\x12\r\n\x05index\x18\x01 \x02(\t\x12\x15\n\rcriterionDesc\x18\x02 \x02(\t\x12\x0f\n\x07ntvIdxs\x18\x03 \x03(\x03\x12\x0f\n\x07numSigs\x18\x04 \x02(\x03\"?\n\x13SelectorTablesReply\x12(\n\x03sig\x18\x01 \x03(\x0b\x32\x1b.allego.SelTableSignalGroup\"\xfa\x02\n\x10\x44\x61taSourceStatus\x12%\n\x04type\x18\x01 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12\x10\n\x08\x64uration\x18\x04 \x02(\x01\x12(\n\x0bsignalGroup\x18\x06 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x17\n\x0fnumTotalSamples\x18\x07 \x02(\x03\x12\x12\n\nsampleFreq\x18\t \x01(\x01\x12\x0b\n\x03uid\x18\n \x02(\t\x12\x16\n\x0e\x64\x61taSourceType\x18\x0b \x02(\t\x12\x10\n\x08\x66ileType\x18\x0c \x02(\t\x12\x0c\n\x04mode\x18\r \x02(\t\x12\r\n\x05label\x18\x0e \x02(\t\x12\x0c\n\x04path\x18\x0f \x02(\t\x12\x14\n\x0c\x62\x61seFileName\x18\x10 \x02(\t\x12\x1d\n\x02tR\x18\x11 \x01(\x0b\x32\x11.allego.TimeRange\x12\x14\n\x0ckpiDsourceID\x18\x12 \x01(\t*\x96\x02\n\x0eRadixFileTypes\x12\x07\n\x03RHD\x10\x00\x12\x08\n\x04XDAT\x10\x01\x12\x07\n\x03\x43SV\x10\x02\x12\x08\n\x04HDF5\x10\x03\x12\x08\n\x04NEX5\x10\x04\x12\x07\n\x03NWB\x10\x05\x12\x10\n\x0c\x42IOINTERFACE\x10\x07\x12\r\n\tKILOSORT2\x10\x08\x12\x07\n\x03\x41NC\x10\t\x12\x0f\n\x0bSPKTRAIN_MU\x10\n\x12\x1b\n\x17\x42IO_RADIENS_EXPORT_HDF5\x10\x0b\x12\x1b\n\x17\x42IO_RADIENS_EXPORT_MAT5\x10\x0c\x12\x07\n\x03NSX\x10\r\x12\x07\n\x03PL2\x10\x0e\x12\x07\n\x03TDT\x10\x0f\x12\n\n\x06SPIKES\x10\x10\x12\x07\n\x03KPI\x10\x11\x12\x15\n\x11UNKNOWN_FILE_TYPE\x10\x12\x12\x0f\n\x0bMEAREC_HDF5\x10\x13*1\n\nSignalType\x12\x07\n\x03PRI\x10\x00\x12\x07\n\x03\x41UX\x10\x01\x12\x07\n\x03\x44IN\x10\x02\x12\x08\n\x04\x44OUT\x10\x03*:\n\x0fResampleRoutine\x12\t\n\x05NAIVE\x10\x00\x12\r\n\tRETENTIVE\x10\x01\x12\r\n\tANTIALIAS\x10\x03*>\n\x04Port\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01\x12\x05\n\x01\x43\x10\x02\x12\x05\n\x01\x44\x10\x03\x12\x05\n\x01\x45\x10\x04\x12\x05\n\x01\x46\x10\x05\x12\x05\n\x01G\x10\x06\x12\x05\n\x01H\x10\x07*2\n\x0cWorkspaceApp\x12\n\n\x06\x41llego\x10\x00\x12\n\n\x06\x43urate\x10\x01\x12\n\n\x06Videre\x10\x02*\xa0\x01\n\x11WorkspaceCommands\x12\x0f\n\x0bWSPACE_Save\x10\x00\x12\x11\n\rWSPACE_SaveAs\x10\x01\x12\x11\n\rWSPACE_Export\x10\x02\x12\x11\n\rWSPACE_Import\x10\x03\x12\x11\n\rWSPACE_Delete\x10\x04\x12\x11\n\rWSPACE_Switch\x10\x07\x12\x1b\n\x17WSPACE_SwitchToLastUsed\x10\x08*C\n\x14GetWorkspaceCommands\x12\x13\n\x0fGET_WSPACE_List\x10\x01\x12\x16\n\x12GET_WSPACE_Current\x10\x02*8\n\x11RadiensServerType\x12\x10\n\x0c\x41llegoserver\x10\x00\x12\x11\n\rRadiensserver\x10\x01*\xae\x01\n\x0fGrpcServiceType\x12\x0f\n\x0b\x41LLEGO_CORE\x10\x00\x12\x11\n\rALLEGO_PCACHE\x10\x01\x12\x0e\n\nALLEGO_KPI\x10\x02\x12\x12\n\x0e\x41LLEGO_NEURONS\x10\x03\x12\x10\n\x0cRADIENS_CORE\x10\x04\x12\x18\n\x14RADIENS_SPIKE_SORTER\x10\x05\x12\x0f\n\x0bRADIENS_DEV\x10\x06\x12\x16\n\x12RADIENS_DASHBOARDS\x10\x07*?\n\x0e\x44\x65vDatasetType\x12\x08\n\x04\x42\x41SE\x10\x00\x12\t\n\x05TRAIN\x10\x01\x12\x0e\n\nVALIDATION\x10\x02\x12\x08\n\x04TEST\x10\x03*C\n\rPSDWindowType\x12\x0f\n\x0bHAMMING_p01\x10\x00\x12\x0f\n\x0bHAMMING_p05\x10\x01\x12\x10\n\x0cPASS_THROUGH\x10\x02*/\n\nPSDScaling\x12\x10\n\x0cPSD_SPECTRUM\x10\x00\x12\x0f\n\x0bPSD_DENSITY\x10\x01*X\n\x0e\x44\x61taSourceSort\x12\x10\n\x0c\x44SOURCE_DATE\x10\x00\x12\x10\n\x0c\x44SOURCE_NAME\x10\x01\x12\x10\n\x0c\x44SOURCE_SIZE\x10\x02\x12\x10\n\x0c\x44SOURCE_TYPE\x10\x03*.\n\x0fSignalGroupType\x12\x11\n\rPRIMARY_CACHE\x10\x00\x12\x08\n\x04\x46ILE\x10\x03*\x81\x01\n\x07\x44SPType\x12\x0b\n\x07LOWPASS\x10\x00\x12\x0c\n\x08HIGHPASS\x10\x01\x12\x0c\n\x08\x42\x41NDPASS\x10\x02\x12\t\n\x05NOTCH\x10\x03\x12\x0c\n\x08\x42\x41NDSTOP\x10\x04\x12\x07\n\x03\x43\x41R\x10\x05\x12\x15\n\x11VIRTUAL_REFERENCE\x10\x06\x12\x14\n\x10PAIRED_REFERENCE\x10\x07*9\n\x0b\x46ilterStage\x12\x12\n\x0eSTAGE_HARDWARE\x10\x00\x12\n\n\x06STAGE1\x10\x01\x12\n\n\x06STAGE2\x10\x02*\xd3\x02\n\x0e\x46\x65\x61tureLicense\x12\x1a\n\x16\x46\x65\x61t_NoLicenseRequired\x10\x00\x12\x0c\n\x08\x46\x65\x61t_Any\x10\x01\x12\x0f\n\x0b\x46\x65\x61t_Power9\x10\x02\x12\x11\n\rFeat_RadixAPI\x10\x03\x12\x0e\n\nFeat_Scope\x10\x04\x12\x13\n\x0f\x46\x65\x61t_Electrodes\x10\x05\x12\x13\n\x0f\x46\x65\x61t_HDSnapshot\x10\x06\x12\x12\n\x0e\x46\x65\x61t_Impedance\x10\x07\x12\x10\n\x0c\x46\x65\x61t_Monitor\x10\x08\x12\x16\n\x12\x46\x65\x61t_SignalMetrics\x10\t\x12\x19\n\x15\x46\x65\x61t_SignalProcessing\x10\n\x12\x0f\n\x0b\x46\x65\x61t_System\x10\x0b\x12\x12\n\x0e\x46\x65\x61t_SpikeGrid\x10\x0c\x12\x14\n\x10\x46\x65\x61t_SpikeSorter\x10\r\x12\x0f\n\x0b\x46\x65\x61t_Raster\x10\x0e\x12\x14\n\x10\x46\x65\x61t_ThreeDModel\x10\x0f*\xed\x01\n\x10SummaryStatsEnum\x12\x10\n\x0cSS_STAT_MEAN\x10\x00\x12\x0e\n\nSS_STAT_SD\x10\x01\x12\x10\n\x0cSS_STAT_MODE\x10\x02\x12\x0f\n\x0bSS_STAT_MIN\x10\x03\x12\x0f\n\x0bSS_STAT_MAX\x10\x04\x12\x16\n\x12SS_STAT_MODE_COUNT\x10\x05\x12\x12\n\x0eSS_STAT_MEDIAN\x10\x06\x12\x0f\n\x0bSS_STAT_Q25\x10\x07\x12\x0f\n\x0bSS_STAT_Q75\x10\x08\x12\x10\n\x0cSS_STAT_SKEW\x10\t\x12\x14\n\x10SS_STAT_KURTOSIS\x10\n\x12\r\n\tSS_STAT_N\x10\x0b*_\n\x0eKpiMetricsMode\x12\x18\n\x14Kpi_MetricsMode_Base\x10\x00\x12\x17\n\x13Kpi_MetricsMode_Avg\x10\x01\x12\x1a\n\x16Kpi_MetricsMode_Stream\x10\x02*\xa1\x06\n\x0eKpiMetricsEnum\x12\x0f\n\x0bKPI_NUM_PTS\x10\x00\x12\x13\n\x0fKPI_NUM_PTS_ISI\x10\x01\x12\x0f\n\x0bKPI_DUR_SEC\x10\x02\x12\x0c\n\x08KPI_MEAN\x10\x03\x12\x0b\n\x07KPI_MIN\x10\x04\x12\x0f\n\x0bKPI_MIN_ISI\x10\x05\x12\x0b\n\x07KPI_MAX\x10\x06\x12\x0f\n\x0bKPI_MAX_ISI\x10\x07\x12\x0f\n\x0bKPI_MAX_ABS\x10\x08\x12\x13\n\x0fKPI_MAX_ABS_ISI\x10\t\x12\x15\n\x11KPI_TIMESTAMP_MIN\x10\n\x12\x15\n\x11KPI_TIMESTAMP_MAX\x10\x0b\x12\x18\n\x14KPI_MAX_MIN_DIFF_ABS\x10\x0c\x12\x1c\n\x18KPI_MAX_MIN_DIFF_ABS_ISI\x10\r\x12\n\n\x06KPI_SD\x10\x0e\x12\x0e\n\nKPI_SD_ISI\x10\x0f\x12\x0b\n\x07KPI_VAR\x10\x10\x12\x0f\n\x0bKPI_VAR_ISI\x10\x11\x12\x0b\n\x07KPI_RMS\x10\x12\x12\x0f\n\x0bKPI_RMS_ISI\x10\x13\x12\x10\n\x0cKPI_NOISE_UV\x10\x14\x12\x0b\n\x07KPI_SNR\x10\x15\x12\x12\n\x0eKPI_NUM_EVENTS\x10\x16\x12\x12\n\x0eKPI_EVENT_RATE\x10\x17\x12\x11\n\rKPI_EVENT_MAX\x10\x18\x12\x11\n\rKPI_EVENT_MIN\x10\x19\x12\x15\n\x11KPI_EVENT_MAX_ABS\x10\x1a\x12\x1e\n\x1aKPI_EVENT_MAX_MIN_DIFF_ABS\x10\x1b\x12\x1b\n\x17KPI_EVENT_TIMESTAMP_MIN\x10\x1c\x12\x1b\n\x17KPI_EVENT_TIMESTAMP_MAX\x10\x1d\x12\x1f\n\x1bKPI_EVENT_TIMESTAMP_MAX_ABS\x10\x1e\x12(\n$KPI_EVENT_TIMESTAMP_MAX_MIN_DIFF_ABS\x10\x1f\x12\x10\n\x0cKPI_MEAN_MAX\x10 \x12\x10\n\x0cKPI_MEAN_MIN\x10!\x12\x14\n\x10KPI_MEAN_MAX_ABS\x10\"\x12#\n\x1fKPI_EVENT_MEAN_MAX_MIN_DIFF_ABS\x10#\x12\"\n\x1eKPI_MAX_MIN_DIFF_ABS_AMPLIFIED\x10$*\x8b\x01\n\x13KpiMetricsStatsEnum\x12\x1e\n\x1aKPI_BDL_METRICS_STATS_MEAN\x10\x00\x12\x1d\n\x19KPI_BDL_METRICS_STATS_MAX\x10\x01\x12\x1d\n\x19KPI_BDL_METRICS_STATS_MIN\x10\x02\x12\x16\n\x12KPI_BDL_METRICS_SD\x10\x03*\xc0\x02\n\x19KpiBundlePacketsStatsEnum\x12\x14\n\x10KPI_BDL_NUM_SIGS\x10\x00\x12\x13\n\x0fKPI_BDL_DUR_SEC\x10\x01\x12\x1d\n\x19KPI_BDL_NUM_SIGS_W_EVENTS\x10\x02\x12\x15\n\x11KPI_BDL_SIG_YIELD\x10\x03\x12\x13\n\x0fKPI_BDL_RMS_AVG\x10\x04\x12\x13\n\x0fKPI_BDL_SNR_AVG\x10\x05\x12\x13\n\x0fKPI_BDL_SIG_MAX\x10\x06\x12\x13\n\x0fKPI_BDL_SIG_MIN\x10\x07\x12\x18\n\x14KPI_BDL_NOISE_UV_AVG\x10\x08\x12\x1c\n\x18KPI_BDL_NUM_EVENTS_TOTAL\x10\t\x12\x1a\n\x16KPI_BDL_NUM_EVENTS_AVG\x10\n\x12\x1a\n\x16KPI_BDL_EVENT_RATE_AVG\x10\x0b*F\n\x10TimeRangeSelMode\x12\x0e\n\nTRS_SUBSET\x10\x00\x12\x0f\n\x0bTRS_TO_HEAD\x10\x01\x12\x11\n\rTRS_FROM_HEAD\x10\x02*e\n\rKpiScannerCmd\x12\x13\n\x0fKPI_SCANNER_OFF\x10\x00\x12\x1e\n\x1aKPI_SCANNER_BESPOKE_SPRINT\x10\x01\x12\x1f\n\x1bKPI_SCANNER_STANDARD_SPRINT\x10\x02*N\n\x16OutfitterComponentType\x12\x16\n\x12OUTFIT_COMP_SENSOR\x10\x00\x12\x1c\n\x18OUTFIT_COMP_SPIKE_SORTER\x10\x01*}\n\x0eWorldNodeLabel\x12\x12\n\x0eWORLD_NODE_ORG\x10\x01\x12\x12\n\x0eWORLD_NODE_LAB\x10\x02\x12\x13\n\x0fWORLD_NODE_USER\x10\x03\x12\x18\n\x14WORLD_NODE_CAT_PROBE\x10\x04\x12\x14\n\x10WORLD_NODE_PROBE\x10\x05*\'\n\x0eWorldEdgeLabel\x12\x15\n\x11WORLD_EDGE_MEMBER\x10\x01*`\n\x12WorldEdgeDirection\x12\x18\n\x14WORLD_EDGE_DIR_RIGHT\x10\x01\x12\x17\n\x13WORLD_EDGE_DIR_LEFT\x10\x02\x12\x17\n\x13WORLD_EDGE_DIR_BOTH\x10\x03*\x9f\x01\n\x0cUserRoleType\x12\x0b\n\x07USER_PI\x10\x01\x12\x12\n\x0eUSER_SCIENTIST\x10\x02\x12\x11\n\rUSER_POST_DOC\x10\x03\x12\x15\n\x11USER_GRAD_STUDENT\x10\x04\x12\x13\n\x0fUSER_UG_STUDENT\x10\x05\x12\x10\n\x0cUSER_MANAGER\x10\x06\x12\r\n\tUSER_TECH\x10\x07\x12\x0e\n\nUSER_OTHER\x10\x08*G\n\rManageNodeCmd\x12\x10\n\x0cNODE_CMD_NEW\x10\x01\x12\x12\n\x0eNODE_CMD_MERGE\x10\x02\x12\x10\n\x0cNODE_CMD_DEL\x10\x03*\xe8\x01\n\rWorldQueryCmd\x12\x15\n\x11WQ_LIST_ALL_USERS\x10\x01\x12\x14\n\x10WQ_LIST_ALL_LABS\x10\x02\x12\x14\n\x10WQ_LIST_ALL_ORGS\x10\x03\x12\x1a\n\x16WQ_LIST_ALL_CAT_PROBES\x10\x04\x12\x16\n\x12WQ_LIST_ALL_PROBES\x10\x05\x12\x18\n\x14WQ_CAT_PROBE_BY_NAME\x10\x06\x12\x11\n\rWQ_USER_BY_ID\x10\x07\x12\x19\n\x15WQ_USER_AND_LAB_BY_ID\x10\x08\x12\x18\n\x14WQ2_LIST_ALL_DEVICES\x10\x1e*\x82\x02\n\x11TransformNodeType\x12\x10\n\x0cNOTCH_FILTER\x10\x00\x12\x13\n\x0f\x42\x41NDPASS_FILTER\x10\x01\x12\x13\n\x0f\x42\x41NDSTOP_FILTER\x10\x02\x12\x13\n\x0fHIGHPASS_FILTER\x10\x03\x12\x12\n\x0eLOWPASS_FILTER\x10\x04\x12\x0e\n\nPAIRED_REF\x10\x05\x12\x0f\n\x0bVIRTUAL_REF\x10\x06\x12\x0b\n\x07\x43\x41R_REF\x10\x07\x12\x0e\n\nSLICE_TIME\x10\t\x12\x12\n\x0eSLICE_CHANNELS\x10\n\x12\n\n\x06SOURCE\x10\x0b\x12\x08\n\x04SINK\x10\x0c\x12\x0e\n\nDOWNSAMPLE\x10\r\x12\x10\n\x0cREMAP_SENSOR\x10\x0e*\xdf\x01\n\x17SpikeSorterParamCommand\x12\x14\n\x10SORTER_THR_LEVEL\x10\x01\x12\x17\n\x13SORTER_THR_LEVEL_SD\x10\x04\x12\x12\n\x0eSORTER_THR_WDW\x10\x08\x12\x19\n\x15SORTER_WEAK_THR_LEVEL\x10\n\x12\x1c\n\x18SORTER_WEAK_THR_LEVEL_SD\x10\r\x12\x11\n\rSORTER_SHADOW\x10\x11\x12\x17\n\x13SORTER_THR_ACTIVATE\x10\x13\x12\x1c\n\x18SORTER_WEAK_THR_ACTIVATE\x10\x15*\x86\x04\n\x10StatusPollFields\x12\x19\n\x15PORT_CONNECTION_STATE\x10\x00\x12\x14\n\x10RECORDING_ERRORS\x10\x01\x12\x15\n\x11STREAM_TIME_RANGE\x10\x02\x12\x11\n\rSTREAM_STATUS\x10\x03\x12\x11\n\rRECORD_STATUS\x10\x04\x12\x16\n\x12GPIO_CHANNEL_COUNT\x10\x05\x12\x10\n\x0cIS_CONNECTED\x10\x06\x12\x0e\n\nRECORD_DUR\x10\x07\x12\x11\n\rBACKBONE_MODE\x10\t\x12\x10\n\x0cSIGNAL_GROUP\x10\n\x12\x14\n\x10SINAPS_REGISTERS\x10\x0b\x12\x14\n\x10RECORDING_CONFIG\x10\x0c\x12\x0b\n\x07\x46ILTERS\x10\r\x12\x17\n\x13\x45VENT_THRESH_PARAMS\x10\x0e\x12\x10\n\x0c\x44\x41\x43_REGISTER\x10\x0f\x12\x10\n\x0c\x44IO_REGISTER\x10\x10\x12\x10\n\x0cTRIGGER_MODE\x10\x11\x12\x11\n\rCABLE_LENGTHS\x10\x12\x12\x11\n\rEVENT_VIEWERS\x10\x13\x12\x0f\n\x0bSAMPLE_RATE\x10\x14\x12\x0e\n\nALL_FIELDS\x10\x15\x12\x16\n\x12SPIKE_SORTER_STATE\x10\x16\x12\x0f\n\x0bSTIM_PARAMS\x10\x17\x12\x19\n\x15SPIKE_SORTER_WARNINGS\x10\x18\x12\x12\n\x0eSTIM_STEP_SIZE\x10\x19*\x1b\n\rDashboardType\x12\n\n\x06\x44\x41SH_1\x10\x00*N\n\x10\x44\x61shboardCommand\x12\x11\n\rDASH_CMD_OPEN\x10\x00\x12\x12\n\x0e\x44\x41SH_CMD_CLOSE\x10\x01\x12\x13\n\x0f\x44\x41SH_CMD_UPDATE\x10\x02\x42\x15Z\x13internal/radix/grpc')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\023internal/radix/grpc'
  _GETWORKSPACEREPLY_WORKSPACEDESCENTRY._options = None
  _GETWORKSPACEREPLY_WORKSPACEDESCENTRY._serialized_options = b'8\001'
  _SERVERSPEC_SERVICEENTRY._options = None
  _SERVERSPEC_SERVICEENTRY._serialized_options = b'8\001'
  _GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY._options = None
  _GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY._serialized_options = b'8\001'
  _SIGNALGROUPUNITS_UNITSENTRY._options = None
  _SIGNALGROUPUNITS_UNITSENTRY._serialized_options = b'8\001'
  _UPDATESIGNALGROUPREQUEST.fields_by_name['ntvChanIdx']._options = None
  _UPDATESIGNALGROUPREQUEST.fields_by_name['ntvChanIdx']._serialized_options = b'\020\001'
  _RADIXFILETYPES._serialized_start=24598
  _RADIXFILETYPES._serialized_end=24876
  _SIGNALTYPE._serialized_start=24878
  _SIGNALTYPE._serialized_end=24927
  _RESAMPLEROUTINE._serialized_start=24929
  _RESAMPLEROUTINE._serialized_end=24987
  _PORT._serialized_start=24989
  _PORT._serialized_end=25051
  _WORKSPACEAPP._serialized_start=25053
  _WORKSPACEAPP._serialized_end=25103
  _WORKSPACECOMMANDS._serialized_start=25106
  _WORKSPACECOMMANDS._serialized_end=25266
  _GETWORKSPACECOMMANDS._serialized_start=25268
  _GETWORKSPACECOMMANDS._serialized_end=25335
  _RADIENSSERVERTYPE._serialized_start=25337
  _RADIENSSERVERTYPE._serialized_end=25393
  _GRPCSERVICETYPE._serialized_start=25396
  _GRPCSERVICETYPE._serialized_end=25570
  _DEVDATASETTYPE._serialized_start=25572
  _DEVDATASETTYPE._serialized_end=25635
  _PSDWINDOWTYPE._serialized_start=25637
  _PSDWINDOWTYPE._serialized_end=25704
  _PSDSCALING._serialized_start=25706
  _PSDSCALING._serialized_end=25753
  _DATASOURCESORT._serialized_start=25755
  _DATASOURCESORT._serialized_end=25843
  _SIGNALGROUPTYPE._serialized_start=25845
  _SIGNALGROUPTYPE._serialized_end=25891
  _DSPTYPE._serialized_start=25894
  _DSPTYPE._serialized_end=26023
  _FILTERSTAGE._serialized_start=26025
  _FILTERSTAGE._serialized_end=26082
  _FEATURELICENSE._serialized_start=26085
  _FEATURELICENSE._serialized_end=26424
  _SUMMARYSTATSENUM._serialized_start=26427
  _SUMMARYSTATSENUM._serialized_end=26664
  _KPIMETRICSMODE._serialized_start=26666
  _KPIMETRICSMODE._serialized_end=26761
  _KPIMETRICSENUM._serialized_start=26764
  _KPIMETRICSENUM._serialized_end=27565
  _KPIMETRICSSTATSENUM._serialized_start=27568
  _KPIMETRICSSTATSENUM._serialized_end=27707
  _KPIBUNDLEPACKETSSTATSENUM._serialized_start=27710
  _KPIBUNDLEPACKETSSTATSENUM._serialized_end=28030
  _TIMERANGESELMODE._serialized_start=28032
  _TIMERANGESELMODE._serialized_end=28102
  _KPISCANNERCMD._serialized_start=28104
  _KPISCANNERCMD._serialized_end=28205
  _OUTFITTERCOMPONENTTYPE._serialized_start=28207
  _OUTFITTERCOMPONENTTYPE._serialized_end=28285
  _WORLDNODELABEL._serialized_start=28287
  _WORLDNODELABEL._serialized_end=28412
  _WORLDEDGELABEL._serialized_start=28414
  _WORLDEDGELABEL._serialized_end=28453
  _WORLDEDGEDIRECTION._serialized_start=28455
  _WORLDEDGEDIRECTION._serialized_end=28551
  _USERROLETYPE._serialized_start=28554
  _USERROLETYPE._serialized_end=28713
  _MANAGENODECMD._serialized_start=28715
  _MANAGENODECMD._serialized_end=28786
  _WORLDQUERYCMD._serialized_start=28789
  _WORLDQUERYCMD._serialized_end=29021
  _TRANSFORMNODETYPE._serialized_start=29024
  _TRANSFORMNODETYPE._serialized_end=29282
  _SPIKESORTERPARAMCOMMAND._serialized_start=29285
  _SPIKESORTERPARAMCOMMAND._serialized_end=29508
  _STATUSPOLLFIELDS._serialized_start=29511
  _STATUSPOLLFIELDS._serialized_end=30029
  _DASHBOARDTYPE._serialized_start=30031
  _DASHBOARDTYPE._serialized_end=30058
  _DASHBOARDCOMMAND._serialized_start=30060
  _DASHBOARDCOMMAND._serialized_end=30138
  _OFFLINELICENSESTATUS._serialized_start=57
  _OFFLINELICENSESTATUS._serialized_end=121
  _FIRMWAREVERSION._serialized_start=123
  _FIRMWAREVERSION._serialized_end=190
  _RADIXENVIRONMENT._serialized_start=192
  _RADIXENVIRONMENT._serialized_end=299
  _STANDARDREQUEST._serialized_start=301
  _STANDARDREQUEST._serialized_end=334
  _STANDARDREPLY._serialized_start=336
  _STANDARDREPLY._serialized_end=383
  _DACOFFREQUEST._serialized_start=385
  _DACOFFREQUEST._serialized_end=423
  _WORKSPACEDESCRIPTOR._serialized_start=426
  _WORKSPACEDESCRIPTOR._serialized_end=612
  _WORKSPACECONTROLREQUEST._serialized_start=615
  _WORKSPACECONTROLREQUEST._serialized_end=799
  _GETWORKSPACEREQUEST._serialized_start=802
  _GETWORKSPACEREQUEST._serialized_end=1013
  _GETWORKSPACEREPLY._serialized_start=1016
  _GETWORKSPACEREPLY._serialized_end=1187
  _GETWORKSPACEREPLY_WORKSPACEDESCENTRY._serialized_start=1106
  _GETWORKSPACEREPLY_WORKSPACEDESCENTRY._serialized_end=1187
  _GETRADIENSSERVERSREQUEST._serialized_start=1189
  _GETRADIENSSERVERSREQUEST._serialized_end=1285
  _SERVERSPEC._serialized_start=1288
  _SERVERSPEC._serialized_end=1567
  _SERVERSPEC_GRPCSERVICE._serialized_start=1429
  _SERVERSPEC_GRPCSERVICE._serialized_end=1456
  _SERVERSPEC_SPAWNEDPROCESS._serialized_start=1458
  _SERVERSPEC_SPAWNEDPROCESS._serialized_end=1487
  _SERVERSPEC_SERVICEENTRY._serialized_start=1489
  _SERVERSPEC_SERVICEENTRY._serialized_end=1567
  _RADIENSSERVERSREPLY._serialized_start=1569
  _RADIENSSERVERSREPLY._serialized_end=1675
  _SIGNALGROUPIDREQUEST._serialized_start=1677
  _SIGNALGROUPIDREQUEST._serialized_end=1722
  _SIGNALMAP._serialized_start=1725
  _SIGNALMAP._serialized_end=1921
  _GPIOCHANNELCOUNT._serialized_start=1923
  _GPIOCHANNELCOUNT._serialized_end=1984
  _PORTCHANNELCOUNT._serialized_start=1986
  _PORTCHANNELCOUNT._serialized_end=2054
  _SETPORTREQUEST._serialized_start=2056
  _SETPORTREQUEST._serialized_end=2137
  _HDSNAPSHOTREQUEST._serialized_start=2140
  _HDSNAPSHOTREQUEST._serialized_end=2494
  _HDSNAPSHOTREQUEST_SELECTEDSIGNALS._serialized_start=2456
  _HDSNAPSHOTREQUEST_SELECTEDSIGNALS._serialized_end=2494
  _HDSNAPSHOTREQUEST2._serialized_start=2497
  _HDSNAPSHOTREQUEST2._serialized_end=2647
  _RADIENSPYGRAPHICSARGS._serialized_start=2649
  _RADIENSPYGRAPHICSARGS._serialized_end=2725
  _PSDREQUEST._serialized_start=2728
  _PSDREQUEST._serialized_end=3077
  _PSD._serialized_start=3080
  _PSD._serialized_end=3369
  _RADIENSPYGRAPHICSREQUEST._serialized_start=3371
  _RADIENSPYGRAPHICSREQUEST._serialized_end=3472
  _SIGSELECTOR._serialized_start=3474
  _SIGSELECTOR._serialized_end=3568
  _HDSNAPSHOTMETA._serialized_start=3570
  _HDSNAPSHOTMETA._serialized_end=3663
  _HDSNAPSHOT._serialized_start=3666
  _HDSNAPSHOT._serialized_end=3953
  _HDSNAPSHOT2._serialized_start=3955
  _HDSNAPSHOT2._serialized_end=4019
  _GETSIGNALSREQUEST._serialized_start=4022
  _GETSIGNALSREQUEST._serialized_end=4463
  _GETSIGNALSREQUEST_GETSIGSPARAMS._serialized_start=4124
  _GETSIGNALSREQUEST_GETSIGSPARAMS._serialized_end=4463
  _RAWSIGNALS._serialized_start=4465
  _RAWSIGNALS._serialized_end=4556
  _SIGNALS2._serialized_start=4559
  _SIGNALS2._serialized_end=4790
  _LISTSENSORSPECSREPLY._serialized_start=4793
  _LISTSENSORSPECSREPLY._serialized_end=5054
  _LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT._serialized_start=4996
  _LISTSENSORSPECSREPLY_SPECWITHCHANNELCOUNT._serialized_end=5054
  _LISTDATASOURCESREQUEST._serialized_start=5056
  _LISTDATASOURCESREQUEST._serialized_end=5156
  _SORTMAP._serialized_start=5158
  _SORTMAP._serialized_end=5186
  _GETSIGNALGROUPIDSREPLY._serialized_start=5188
  _GETSIGNALGROUPIDSREPLY._serialized_end=5250
  _GETSORTERIDMAPREPLY._serialized_start=5253
  _GETSORTERIDMAPREPLY._serialized_end=5413
  _GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY._serialized_start=5345
  _GETSORTERIDMAPREPLY_SIGTOSORTMAPENTRY._serialized_end=5413
  _DATASOURCE._serialized_start=5416
  _DATASOURCE._serialized_end=5591
  _FILEDESCRIPTOR._serialized_start=5593
  _FILEDESCRIPTOR._serialized_end=5704
  _TIMESPEC._serialized_start=5707
  _TIMESPEC._serialized_end=5915
  _TIMESPEC_TIMERANGEL._serialized_start=5829
  _TIMESPEC_TIMERANGEL._serialized_end=5860
  _TIMESPEC_TIMESTAMPRANGEL._serialized_start=5862
  _TIMESPEC_TIMESTAMPRANGEL._serialized_end=5903
  _SIGNALSPEC._serialized_start=5918
  _SIGNALSPEC._serialized_end=6108
  _SIGNALSPEC_SITENUML._serialized_start=6034
  _SIGNALSPEC_SITENUML._serialized_end=6061
  _SIGNALSPEC_NTVCHANIDXL._serialized_start=6063
  _SIGNALSPEC_NTVCHANIDXL._serialized_end=6096
  _CHANNELRECORD._serialized_start=6111
  _CHANNELRECORD._serialized_end=6891
  _XYCOORD._serialized_start=6893
  _XYCOORD._serialized_end=6924
  _XYZCOORD._serialized_start=6926
  _XYZCOORD._serialized_end=6969
  _SENSOR._serialized_start=6972
  _SENSOR._serialized_end=7357
  _SENSOR_WIREFRAME._serialized_start=7248
  _SENSOR_WIREFRAME._serialized_end=7357
  _SENSORPORTSPEC._serialized_start=7360
  _SENSORPORTSPEC._serialized_end=7640
  _SIGNALGROUPUNITS._serialized_start=7642
  _SIGNALGROUPUNITS._serialized_end=7758
  _SIGNALGROUPUNITS_UNITSENTRY._serialized_start=7714
  _SIGNALGROUPUNITS_UNITSENTRY._serialized_end=7758
  _SIGNALGROUP._serialized_start=7761
  _SIGNALGROUP._serialized_end=8017
  _CREATESIGNALGROUPREQUEST._serialized_start=8020
  _CREATESIGNALGROUPREQUEST._serialized_end=8155
  _SUBOPSORT._serialized_start=8157
  _SUBOPSORT._serialized_end=8272
  _SUBOPSORT_SORTFIELD._serialized_start=8213
  _SUBOPSORT_SORTFIELD._serialized_end=8272
  _UPDATESIGNALGROUPREQUEST._serialized_start=8275
  _UPDATESIGNALGROUPREQUEST._serialized_end=8696
  _UPDATESIGNALGROUPREQUEST_OPERATION._serialized_start=8577
  _UPDATESIGNALGROUPREQUEST_OPERATION._serialized_end=8643
  _UPDATESIGNALGROUPREQUEST_SUBOPERATION._serialized_start=8645
  _UPDATESIGNALGROUPREQUEST_SUBOPERATION._serialized_end=8680
  _SLICESIGNALGROUPSPEC._serialized_start=8698
  _SLICESIGNALGROUPSPEC._serialized_end=8782
  _SLICESIGNALGROUPREQUEST._serialized_start=8784
  _SLICESIGNALGROUPREQUEST._serialized_end=8872
  _SLICESIGNALGROUPREPLY._serialized_start=8875
  _SLICESIGNALGROUPREPLY._serialized_end=9011
  _LICENSESTATUS._serialized_start=9013
  _LICENSESTATUS._serialized_end=9028
  _SETDSPGROUPREQUEST._serialized_start=9030
  _SETDSPGROUPREQUEST._serialized_end=9147
  _DSPPARAMS._serialized_start=9150
  _DSPPARAMS._serialized_end=9520
  _DSPPARAMS_FREQSPECBAND._serialized_start=9459
  _DSPPARAMS_FREQSPECBAND._serialized_end=9508
  _DSPGROUP._serialized_start=9523
  _DSPGROUP._serialized_end=9656
  _SETSENSORREQUEST._serialized_start=9659
  _SETSENSORREQUEST._serialized_end=9813
  _SENSORPOSITIONTCS._serialized_start=9815
  _SENSORPOSITIONTCS._serialized_end=9924
  _SETSENSORPOSITIONTCSREQUEST._serialized_start=9927
  _SETSENSORPOSITIONTCSREQUEST._serialized_end=10071
  _SITEPOSITIONTCS._serialized_start=10073
  _SITEPOSITIONTCS._serialized_end=10143
  _SETSITEPOSITIONSTCSREQUEST._serialized_start=10145
  _SETSITEPOSITIONSTCSREQUEST._serialized_end=10272
  _FEATURESTARTSTOPREQUEST._serialized_start=10274
  _FEATURESTARTSTOPREQUEST._serialized_end=10363
  _PRIVACYREPLY._serialized_start=10365
  _PRIVACYREPLY._serialized_end=10398
  _SETPRIVACYREQUEST._serialized_start=10400
  _SETPRIVACYREQUEST._serialized_end=10438
  _DENSEMATRIX._serialized_start=10440
  _DENSEMATRIX._serialized_end=10495
  _HISTOGRAM._serialized_start=10497
  _HISTOGRAM._serialized_end=10589
  _KPIMETRICID._serialized_start=10591
  _KPIMETRICID._serialized_end=10680
  _TIMERANGE._serialized_start=10683
  _TIMERANGE._serialized_end=10816
  _BUNDLEREQ._serialized_start=10818
  _BUNDLEREQ._serialized_end=10931
  _KPIMETRICSREQ._serialized_start=10934
  _KPIMETRICSREQ._serialized_end=11091
  _KPIMETRICSDATA._serialized_start=11094
  _KPIMETRICSDATA._serialized_end=11481
  _KPIMETRICSDATA_METRICSTATS._serialized_start=11416
  _KPIMETRICSDATA_METRICSTATS._serialized_end=11481
  _KPIBUNDLEPACKETMETRICS._serialized_start=11483
  _KPIBUNDLEPACKETMETRICS._serialized_end=11602
  _KPIMETRICS._serialized_start=11604
  _KPIMETRICS._serialized_end=11687
  _KPICONTROLREQUEST._serialized_start=11689
  _KPICONTROLREQUEST._serialized_end=11788
  _SETKPIPARAMREQUEST._serialized_start=11790
  _SETKPIPARAMREQUEST._serialized_end=11848
  _GETKPISTATUSREQUEST._serialized_start=11850
  _GETKPISTATUSREQUEST._serialized_end=11894
  _KPISTANDARDREQUEST._serialized_start=11896
  _KPISTANDARDREQUEST._serialized_end=11971
  _KPIFILESTATUS._serialized_start=11974
  _KPIFILESTATUS._serialized_end=12160
  _KPIFILESTATUS_STATE._serialized_start=12037
  _KPIFILESTATUS_STATE._serialized_end=12160
  _KPIFILESTATUS2._serialized_start=12163
  _KPIFILESTATUS2._serialized_end=12746
  _KPIFILESTATUS2_KPI_STATE._serialized_start=12246
  _KPIFILESTATUS2_KPI_STATE._serialized_end=12479
  _KPIFILESTATUS2_DATASOURCE_STATE._serialized_start=12481
  _KPIFILESTATUS2_DATASOURCE_STATE._serialized_end=12594
  _KPIFILESTATUS2_KPIDATASOURCESTATESPEC._serialized_start=12597
  _KPIFILESTATUS2_KPIDATASOURCESTATESPEC._serialized_end=12746
  _KPIFILEMETADATA._serialized_start=12749
  _KPIFILEMETADATA._serialized_end=13002
  _KPIFILEMETADATA_STATE._serialized_start=12817
  _KPIFILEMETADATA_STATE._serialized_end=13002
  _KPISTATUSREPLY._serialized_start=13005
  _KPISTATUSREPLY._serialized_end=13344
  _SIGKPIPARAMRECORD._serialized_start=13347
  _SIGKPIPARAMRECORD._serialized_end=13705
  _ANNOTATEBUNDLE._serialized_start=13707
  _ANNOTATEBUNDLE._serialized_end=13781
  _PROJECTMETADATA._serialized_start=13783
  _PROJECTMETADATA._serialized_end=13876
  _SENSOREXTENDEDMETADATA._serialized_start=13878
  _SENSOREXTENDEDMETADATA._serialized_end=13929
  _GONUMMATRIXLIST._serialized_start=13931
  _GONUMMATRIXLIST._serialized_end=13968
  _RADIXMATRIXLIST._serialized_start=13970
  _RADIXMATRIXLIST._serialized_end=14024
  _RADIXMATRIX._serialized_start=14026
  _RADIXMATRIX._serialized_end=14068
  _RADIXMATRIXBYTES._serialized_start=14070
  _RADIXMATRIXBYTES._serialized_end=14117
  _RADIXSIGNALSLIST._serialized_start=14119
  _RADIXSIGNALSLIST._serialized_end=14175
  _RADIXSIGNALS._serialized_start=14178
  _RADIXSIGNALS._serialized_end=14347
  _VECTORSTRING._serialized_start=14349
  _VECTORSTRING._serialized_end=14374
  _VECTORFLOAT64._serialized_start=14376
  _VECTORFLOAT64._serialized_end=14402
  _VECTORSLICEFLOAT64._serialized_start=14404
  _VECTORSLICEFLOAT64._serialized_end=14475
  _LOGSYSKPISTATUSREPLY._serialized_start=14478
  _LOGSYSKPISTATUSREPLY._serialized_end=14828
  _KPICACHE._serialized_start=14831
  _KPICACHE._serialized_end=15211
  _LOGSYSKPITAILREPLY._serialized_start=15214
  _LOGSYSKPITAILREPLY._serialized_end=15592
  _KPIPORTINFO._serialized_start=15594
  _KPIPORTINFO._serialized_end=15645
  _KPITAILROWS._serialized_start=15648
  _KPITAILROWS._serialized_end=16020
  _WAREHOUSEHEALTHCHECKSPEC._serialized_start=16022
  _WAREHOUSEHEALTHCHECKSPEC._serialized_end=16064
  _OUTFITTERGETDEVICEREQUEST._serialized_start=16066
  _OUTFITTERGETDEVICEREQUEST._serialized_end=16106
  _SENSORCOMPREQUEST._serialized_start=16109
  _SENSORCOMPREQUEST._serialized_end=16267
  _REGISTERSENSORCOMPREQUEST._serialized_start=16269
  _REGISTERSENSORCOMPREQUEST._serialized_end=16391
  _SAVESENSORCOMPINSTANCEREQUEST._serialized_start=16394
  _SAVESENSORCOMPINSTANCEREQUEST._serialized_end=16540
  _PROBEDESC._serialized_start=16542
  _PROBEDESC._serialized_end=16580
  _HEADSTAGEDESC._serialized_start=16582
  _HEADSTAGEDESC._serialized_end=16624
  _GETSENSORCOMPREPLY._serialized_start=16626
  _GETSENSORCOMPREPLY._serialized_end=16722
  _PROBESPEC._serialized_start=16724
  _PROBESPEC._serialized_end=16844
  _HEADSTAGESPEC._serialized_start=16847
  _HEADSTAGESPEC._serialized_end=16983
  _PROBEMODEL._serialized_start=16986
  _PROBEMODEL._serialized_end=17576
  _PROBEMODEL_PROBESITEDESC._serialized_start=17223
  _PROBEMODEL_PROBESITEDESC._serialized_end=17445
  _PROBEMODEL_PROBEWIREFRAME._serialized_start=17447
  _PROBEMODEL_PROBEWIREFRAME._serialized_end=17541
  _PROBEMODEL_PROBEPTXY._serialized_start=17543
  _PROBEMODEL_PROBEPTXY._serialized_end=17576
  _PROBEMETADATA._serialized_start=17578
  _PROBEMETADATA._serialized_end=17673
  _HEADSTAGEMODEL._serialized_start=17676
  _HEADSTAGEMODEL._serialized_end=17808
  _HEADSTAGEMODEL_HEADSTAGEROW._serialized_start=17757
  _HEADSTAGEMODEL_HEADSTAGEROW._serialized_end=17808
  _HEADSTAGEMETADATA._serialized_start=17810
  _HEADSTAGEMETADATA._serialized_end=17829
  _USERPROFILE._serialized_start=17831
  _USERPROFILE._serialized_end=17884
  _GETCURRENTPROFILEREPLY._serialized_start=17886
  _GETCURRENTPROFILEREPLY._serialized_end=17952
  _GETALLPROFILESREPLY._serialized_start=17954
  _GETALLPROFILESREPLY._serialized_end=18018
  _SETCURRENTPROFILEREQUEST._serialized_start=18020
  _SETCURRENTPROFILEREQUEST._serialized_end=18065
  _MANAGENODEORGPAYLOAD._serialized_start=18068
  _MANAGENODEORGPAYLOAD._serialized_end=18204
  _MANAGENODEORGREQUEST._serialized_start=18206
  _MANAGENODEORGREQUEST._serialized_end=18311
  _MANAGENODEORGREPLY._serialized_start=18313
  _MANAGENODEORGREPLY._serialized_end=18396
  _MANAGENODELABPAYLOAD._serialized_start=18399
  _MANAGENODELABPAYLOAD._serialized_end=18561
  _MANAGENODELABREQUEST._serialized_start=18563
  _MANAGENODELABREQUEST._serialized_end=18668
  _MANAGENODELABREPLY._serialized_start=18670
  _MANAGENODELABREPLY._serialized_end=18753
  _MANAGENODEUSERPAYLOAD._serialized_start=18756
  _MANAGENODEUSERPAYLOAD._serialized_end=18909
  _MANAGENODEUSERREQUEST._serialized_start=18911
  _MANAGENODEUSERREQUEST._serialized_end=19018
  _MANAGENODEUSERREPLY._serialized_start=19020
  _MANAGENODEUSERREPLY._serialized_end=19105
  _CATALOGPROBEPAYLOAD._serialized_start=19107
  _CATALOGPROBEPAYLOAD._serialized_end=19161
  _PROBENODEREQUEST._serialized_start=19163
  _PROBENODEREQUEST._serialized_end=19256
  _PROBENODEREPLY._serialized_start=19258
  _PROBENODEREPLY._serialized_end=19313
  _PROBEPAYLOAD._serialized_start=19315
  _PROBEPAYLOAD._serialized_end=19362
  _EDGEPAYLOAD._serialized_start=19365
  _EDGEPAYLOAD._serialized_end=19658
  _EDGEPAYLOAD_GENERICNODE._serialized_start=19568
  _EDGEPAYLOAD_GENERICNODE._serialized_end=19658
  _WORLDEDGEREQUEST._serialized_start=19660
  _WORLDEDGEREQUEST._serialized_end=19716
  _WORLDEDGEREPLY._serialized_start=19718
  _WORLDEDGEREPLY._serialized_end=19734
  _QUERYWORLDREQUEST._serialized_start=19736
  _QUERYWORLDREQUEST._serialized_end=19805
  _QUERYWORLDREC._serialized_start=19808
  _QUERYWORLDREC._serialized_end=20038
  _QUERYWORLDREPLY._serialized_start=20040
  _QUERYWORLDREPLY._serialized_end=20097
  _HIGHLOWPASSTRANSFORMPARAMS._serialized_start=20099
  _HIGHLOWPASSTRANSFORMPARAMS._serialized_end=20146
  _BANDTRANSFORMPARAMS._serialized_start=20148
  _BANDTRANSFORMPARAMS._serialized_end=20214
  _NOTCHTRANSFORMPARAMS._serialized_start=20216
  _NOTCHTRANSFORMPARAMS._serialized_end=20286
  _CARTRANSFORMPARAMS._serialized_start=20288
  _CARTRANSFORMPARAMS._serialized_end=20308
  _VIRTUALREFTRANSFORMPARAMS._serialized_start=20310
  _VIRTUALREFTRANSFORMPARAMS._serialized_end=20360
  _PAIREDREFTRANSFORMPARAMS._serialized_start=20362
  _PAIREDREFTRANSFORMPARAMS._serialized_end=20437
  _DATASOURCESINKTRANSFORMPARAMS._serialized_start=20439
  _DATASOURCESINKTRANSFORMPARAMS._serialized_end=20544
  _SLICETIMETRANSFORMPARAMS._serialized_start=20546
  _SLICETIMETRANSFORMPARAMS._serialized_end=20608
  _SLICECHANNELSTRANSFORMPARAMS._serialized_start=20610
  _SLICECHANNELSTRANSFORMPARAMS._serialized_end=20720
  _DOWNSAMPLETRANSFORMPARAMS._serialized_start=20722
  _DOWNSAMPLETRANSFORMPARAMS._serialized_end=20771
  _REMAPSENSORTRANSFORMPARAMS._serialized_start=20774
  _REMAPSENSORTRANSFORMPARAMS._serialized_end=20993
  _REMAPSENSORTRANSFORMPARAMS_SENSORSPEC._serialized_start=20868
  _REMAPSENSORTRANSFORMPARAMS_SENSORSPEC._serialized_end=20993
  _POSITION._serialized_start=20995
  _POSITION._serialized_end=21027
  _TRANSFORMNODE._serialized_start=21030
  _TRANSFORMNODE._serialized_end=21822
  _TRANSFORMEDGE._serialized_start=21824
  _TRANSFORMEDGE._serialized_end=21883
  _PROTOCOL._serialized_start=21885
  _PROTOCOL._serialized_end=22001
  _PROTOCOLREQUEST._serialized_start=22003
  _PROTOCOLREQUEST._serialized_end=22040
  _RENAMEPROTOCOLREQUEST._serialized_start=22042
  _RENAMEPROTOCOLREQUEST._serialized_end=22108
  _GETALLPROTOCOLSREPLY._serialized_start=22110
  _GETALLPROTOCOLSREPLY._serialized_end=22169
  _APPLYPROTOCOLPROGRESS._serialized_start=22171
  _APPLYPROTOCOLPROGRESS._serialized_end=22294
  _SPIKESORTERSETPARAMREQUEST._serialized_start=22297
  _SPIKESORTERSETPARAMREQUEST._serialized_end=22451
  _SPIKESORTERSETPARAMSREQUEST._serialized_start=22453
  _SPIKESORTERSETPARAMSREQUEST._serialized_end=22534
  _SPIKESORTERPARAMCOMMANDRECORD._serialized_start=22537
  _SPIKESORTERPARAMCOMMANDRECORD._serialized_end=22832
  _KPIPARAMS._serialized_start=22834
  _KPIPARAMS._serialized_end=22897
  _DACSTREAMREQUEST._serialized_start=22899
  _DACSTREAMREQUEST._serialized_end=22973
  _EVENTVIEWERCONFIG._serialized_start=22976
  _EVENTVIEWERCONFIG._serialized_end=23198
  _EVENTVIEWERID._serialized_start=23200
  _EVENTVIEWERID._serialized_end=23261
  _GETEVENTVIEWEREVENTREQUEST._serialized_start=23263
  _GETEVENTVIEWEREVENTREQUEST._serialized_end=23331
  _EVENTVIEWEREVENTDESC._serialized_start=23333
  _EVENTVIEWEREVENTDESC._serialized_end=23422
  _EVENTVIEWEREVENT._serialized_start=23425
  _EVENTVIEWEREVENT._serialized_end=23568
  _LISTEVENTVIEWEREVENTSREPLY._serialized_start=23570
  _LISTEVENTVIEWEREVENTSREPLY._serialized_end=23667
  _LISTEVENTVIEWERSREPLY._serialized_start=23669
  _LISTEVENTVIEWERSREPLY._serialized_end=23737
  _STATUSPOLLFIELDSTOUPDATEREQUEST._serialized_start=23739
  _STATUSPOLLFIELDSTOUPDATEREQUEST._serialized_end=23790
  _STATUSPOLLFIELDSTOUPDATE._serialized_start=23792
  _STATUSPOLLFIELDSTOUPDATE._serialized_end=23886
  _DASHBOARDCOMMANDREQUEST._serialized_start=23889
  _DASHBOARDCOMMANDREQUEST._serialized_end=24054
  _DASHBOARDCOMMANDREQUEST_ARGS._serialized_start=24009
  _DASHBOARDCOMMANDREQUEST_ARGS._serialized_end=24054
  _SELTABLESIGNALGROUP._serialized_start=24056
  _SELTABLESIGNALGROUP._serialized_end=24149
  _SELECTORTABLESREPLY._serialized_start=24151
  _SELECTORTABLESREPLY._serialized_end=24214
  _DATASOURCESTATUS._serialized_start=24217
  _DATASOURCESTATUS._serialized_end=24595
# @@protoc_insertion_point(module_scope)



import datetime
from collections import namedtuple
from enum import Enum
from pathlib import Path

import numpy as np
import pandas as pd
from radiens.api.api_utils.util import to_file_ext
from radiens.grpc_radiens import (allegoserver_pb2, biointerface_pb2,
                                  common_pb2, datasource_pb2)
from radiens.lib.channel_metadata import ChannelMetadata
from radiens.utils.constants import TimeRange
from radiens.utils.util import (make_neighbors_desc, make_neuron_desc,
                                make_time_range)

# SPIKE_ENSEMBLE = namedtuple("SpikeWaveforms", ['time_range', 'n_pts_waveform', 'num_total_spikes', 'channel'])
SITE_STATS = namedtuple("SiteStats", ['spike_count', 'spike_count_labeled', 'spike_count_unlabeled',
                                      'spike_rate', 'spike_rate_labeled', 'spike_rate_unlabeled',
                                      'noise', 'snr', 'neurons'])
SPK_LABEL = Enum(
    'SpikeLabel', ['LABELED', 'UNLABELED', 'BAD', 'TOTAL'], start=0)
SPIKE_COMP_SHAPE = namedtuple("SpikeComponentShape", [
    'waveform', 'feature', 'feature2', 'zscore'])


class SpikesSet():
    '''
    Radiens container for spike datasets
    '''

    def __init__(self, msg):
        """
        """
        self._time_range = np.array([], dtype=np.float64)
        self._n_pts_wfm = 0
        self._n_spikes_total = 0
        self._chan = {}
        if isinstance(msg, biointerface_pb2.SpikesSpikeDataDenseReply):
            self._time_range = np.array(msg.timeRange, dtype=np.float64)
            self._n_pts_wfm = msg.waveformNPoints
            self._n_spikes_total = msg.totalNSpikes
            _data = np.frombuffer(msg.data, dtype=np.float32)
            offset0 = 0
            for desc in msg.channelDescriptors:
                self._chan[desc.ntvChanIdx] = {'labels': [str(elem) for elem in desc.labels],
                                               'waveform_max': desc.waveformMaxValue,
                                               'waveform_min': desc.waveformMinValue,
                                               'num_spikes': len(desc.labels),
                                               'comp': {
                                               'timestamps': np.array([], np.int64),
                                               'waveforms': np.array([[]], np.float64),
                                               'ftrs': np.array([[]], np.float64),
                                               'ftrs2': np.array([[]], np.float64)},
                                               'neighbors': {'waveforms': np.array([[[]]], np.float64),
                                                             'ntv_chan_idx': np.array([[[]]], np.float64)}
                                               }
                if len(desc.labels) > 0:
                    self._chan[desc.ntvChanIdx]['waveforms'] = np.reshape(
                        _data[offset0:offset0+(self._n_pts_wfm*len(desc.labels))], (self._n_pts_wfm, len(desc.labels)))
                offset0 = offset0 + self._n_pts_wfm*len(desc.labels)

    @ property
    def envelope_time_range(self) -> np.ndarray:
        """
        Envelope time range in sec
        """
        return self._time_range

    @ property
    def num_pts_waveform(self) -> int:
        """
        Number of points per waveform
        """
        return self._n_pts_wfm

    @ property
    def num_spikes_total(self) -> int:
        """
        Number of total spikes in the spikes set.
        """
        return self._n_spikes_total

    @ property
    def num_channels(self) -> int:
        """
        Number of channels in the spikes set.
        """
        return len(self._chan)

    def channels(self) -> dict:
        """
        Channel data
        """
        return self._chan

    def has_component(self, comp: str) -> bool:
        """
        Returns true if the object has the requested component
        """
        if comp not in ['timestamps', 'waveforms']:
            raise ValueError('comp not valid, use `timestamps` | `waveforms`')
        return self._reserved_has_component(comp)

    def component_len(self, comp: str) -> bool:
        """
        Returns true if the object has the requested component
        """
        if comp not in ['timestamps', 'waveforms']:
            raise ValueError('comp not valid, use `timestamps` | `waveforms`')
        return self._reserved_has_component(comp)

    def _reserved_has_component(self, comp: str) -> bool:
        if comp not in ['timestamps', 'waveforms', 'ftrs', 'ftrs2']:
            raise ValueError(
                'comp not valid, use [`timestamps`|`waveforms` | `ftrs` | `ftrs2`')
        for _, chan in self.channels().items():
            if chan['num_spikes'] > 0:
                return len(chan['comp'][comp]) > 0
        return False

    def _reserved_component_len(self, comp: str) -> int:
        if comp not in ['timestamps', 'waveforms', 'ftrs', 'ftrs2']:
            raise ValueError(
                'comp not valid, use [`timestamps`|`waveforms` | `ftrs` | `ftrs2`')
        for _, chan in self.channels().items():
            if chan['num_spikes'] > 0:
                return len(chan['comp'][comp])
        return 0


class SpikesMetadata():
    '''
    Radiens container for metadata on spikes datasets
    '''

    def __init__(self, msg):
        """
        """
        if not isinstance(msg, biointerface_pb2.SpikesSpecReply):
            raise ValueError('initialized with wrong data type')
        self._d = {'datasourceID': msg.biointerfaceID, 'datasetUID': msg.datasetUID,
                   'checksum': msg.checksum, 'persist_dur_sec': msg.persistDur,
                   'num_sites': msg.numSites, 'size_bytes': msg.sizeBytes,
                   'enabled_ntv_idxs': msg.enabledSiteNtvChanIdx, 'ni_type': biointerface_pb2.BiointerfaceType.Name(msg.bioType),
                   'req_num_neighbors': msg.reqNumNeighbors, 'nbr_radius': msg.neighborhoodRadiusUm}
        self._tr = make_time_range(pbTR=msg.tR)
        self._sg = ChannelMetadata(msg.sG)

        self._site_stats = SITE_STATS(spike_count=msg.siteStats.spikeCountStats,
                                      spike_count_labeled=msg.siteStats.labeledSpikeCountStats,
                                      spike_count_unlabeled=msg.siteStats.unlabeledSpikeCountStats,
                                      spike_rate=msg.siteStats.spikeRateStats,
                                      spike_rate_labeled=msg.siteStats.labeledSpikeRateStats,
                                      spike_rate_unlabeled=msg.siteStats.unlabeledSpikeRateStats,
                                      noise=msg.siteStats.siteNoiseStats,
                                      snr=msg.siteStats.siteSnrStats,
                                      neurons=msg.siteStats.neuronStats)
        self._sensor_ext_metadata = {
            'instance_UID': msg.sensorExt.sensorInstanceUID}
        self._project_ext_metadata = {'project_UID': msg.project.projectUID, 'case_UID': msg.project.caseUID,
                                      'trial_UID': msg.project.trialUID, 'annotate_UID': msg.project.annotateUID}
        self._site = {'ntv_idx': [], 'neighbor': [], 'enabled': [], 'pos_probe': [], 'pos_tissue': [], 'size_bytes': [],
                      'TR': [], 'spike_TR': [], 'spike_count': [], 'spike_rate': [], 'noise': [], 'snr': [], 'neurons': [],
                      'num_neurons': [], 'spike_comp_len': []}
        for site in msg.site:
            self._site['ntv_idx'].append(site.ntvChanIdx)
            self._site['neighbor'].append(make_neighbors_desc(site.neighbor))
            self._site['enabled'].append(site.isEnabled)
            self._site['pos_probe'].append(site.posProbe)
            self._site['pos_tissue'].append(site.posTissue)
            self._site['size_bytes'].append(site.sizeBytes)
            self._site['TR'].append(make_time_range(pbTR=site.tR))
            self._site['spike_TR'].append(make_time_range(pbTR=site.spikeTR))
            self._site['spike_count'].append(site.spikeCountSite)
            self._site['spike_rate'].append(site.spikeRateSite)
            self._site['noise'].append(site.noiseLevelSd)
            self._site['snr'].append(site.snrSite)
            self._site['neurons'].append(
                [make_neuron_desc(elem) for elem in site.neuron])
            self._site['num_neurons'].append(site.numNeurons)
            self._site['spike_comp_len'].append(SPIKE_COMP_SHAPE(waveform=site.compLen.waveform, feature=site.compLen.feature,
                                                                 feature2=site.compLen.feature2, zscore=site.compLen.zscore))

    @ property
    def time_range(self):
        """
        Envelope time range in sec as a `TimeRange` named tuple.
        """
        return self._tr

    @ property
    def site_metadata(self) -> ChannelMetadata:
        """
        Site metadata
        """
        return self._sg

    @ property
    def site_summary_stats(self) -> pd.DataFrame:
        """
        Table of site summary statistics.  Use the SStat enum in radiens.util.constants for the name of each statistic (row) for each column.  
        """
        return pd.DataFrame({'spike_count': self._site_stats.spike_count[:],
                             'spike_count_labeled': self._site_stats.spike_count_labeled[:],
                             'spike_count_unlabeled': self._site_stats.spike_count_unlabeled[:],
                             'spike_rate': self._site_stats.spike_rate[:],
                             'spike_rate_labeled': self._site_stats.spike_count_labeled[:],
                             'spike_rate_unlabeled': self._site_stats.spike_count_unlabeled[:],
                             'noise': self._site_stats.noise[:],
                             'snr': self._site_stats.snr[:],
                             'neurons': self._site_stats.neurons[:],
                             })

    @ property
    def sensor_ext_metadata(self) -> dict:
        """
        Sensor extended metadata
        """
        return self._sensor_ext_metadata

    @ property
    def project_ext_metadata(self) -> dict:
        """
        Project extended metadata
        """
        return self._project_ext_metadata

    @ property
    def sites(self) -> pd.DataFrame:
        """
        Site data as a pandas DataFrame (i.e. table) where each site is a row. 
        """
        return pd.DataFrame(self._site)

    @ property
    def neurons(self) -> pd.DataFrame:
        """
        Neuron data as a pandas DataFrame where each neuron is a row.
        """
        tidy_rows = []
        for _, row in self.sites.iterrows():
            for neuron in row['neurons']:
                row['neuron'] = neuron
                row['neuron_id'] = neuron[0]
                tidy_rows.append(row)
        return pd.concat(tidy_rows, axis=1).T.reset_index()
